summaryrefslogtreecommitdiffstats
path: root/quanta/components
diff options
context:
space:
mode:
authorTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-12-15 15:51:43 -0600
committerTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-12-15 15:51:43 -0600
commit2b0e1de2ffcca7bb93f1fd8ddd32f74041d0d076 (patch)
treec57406ac640b2ce83ebc0ec0cbc96d0e3e40d9b5 /quanta/components
parentff23fbd0f4265648d9a1d53f4230c3f7c78c4f77 (diff)
downloadtdewebdev-2b0e1de2ffcca7bb93f1fd8ddd32f74041d0d076.tar.gz
tdewebdev-2b0e1de2ffcca7bb93f1fd8ddd32f74041d0d076.zip
Rename a number of old tq methods that are no longer tq specific
Diffstat (limited to 'quanta/components')
-rw-r--r--quanta/components/csseditor/colorrequester.cpp2
-rw-r--r--quanta/components/csseditor/colorslider.cpp6
-rw-r--r--quanta/components/csseditor/csseditor.cpp6
-rw-r--r--quanta/components/csseditor/csseditors.ui12
-rw-r--r--quanta/components/csseditor/cssselector.cpp2
-rw-r--r--quanta/components/csseditor/cssselectors.ui50
-rw-r--r--quanta/components/csseditor/data/config.xml8
-rw-r--r--quanta/components/csseditor/encodingselector.cpp2
-rw-r--r--quanta/components/csseditor/encodingselectors.ui8
-rw-r--r--quanta/components/csseditor/fontfamilychooser.cpp12
-rw-r--r--quanta/components/csseditor/fontfamilychoosers.ui44
-rw-r--r--quanta/components/csseditor/propertysetter.cpp2
-rw-r--r--quanta/components/csseditor/styleeditor.cpp2
-rw-r--r--quanta/components/csseditor/stylesheetparser.cpp4
-rw-r--r--quanta/components/csseditor/tlpeditors.cpp2
-rw-r--r--quanta/components/cvsservice/cvscommitdlgs.ui2
-rw-r--r--quanta/components/cvsservice/cvsservice.cpp20
-rw-r--r--quanta/components/cvsservice/cvsupdatetodlgs.ui8
-rw-r--r--quanta/components/debugger/conditionalbreakpointdialogs.ui14
-rw-r--r--quanta/components/debugger/dbgp/dbgpnetwork.cpp6
-rw-r--r--quanta/components/debugger/dbgp/dbgpsettingss.ui10
-rw-r--r--quanta/components/debugger/dbgp/qbytearrayfifo.cpp2
-rw-r--r--quanta/components/debugger/dbgp/quantadebuggerdbgp.cpp54
-rw-r--r--quanta/components/debugger/dbgp/quantadebuggerdbgp.h2
-rw-r--r--quanta/components/debugger/debuggermanager.cpp12
-rw-r--r--quanta/components/debugger/debuggermanager.h2
-rw-r--r--quanta/components/debugger/debuggerui.cpp6
-rw-r--r--quanta/components/debugger/debuggerui.h6
-rw-r--r--quanta/components/debugger/debuggervariable.cpp6
-rw-r--r--quanta/components/debugger/debuggervariablesets.ui6
-rw-r--r--quanta/components/debugger/gubed/gubedsettingss.ui18
-rw-r--r--quanta/components/debugger/gubed/quantadebuggergubed.cpp70
-rw-r--r--quanta/components/debugger/gubed/quantadebuggergubed.h2
-rw-r--r--quanta/components/debugger/interfaces/debuggerclient.cpp10
-rw-r--r--quanta/components/debugger/interfaces/debuggerclient.h2
-rw-r--r--quanta/components/debugger/interfaces/debuggerinterface.h2
-rw-r--r--quanta/components/debugger/pathmapper.cpp2
-rw-r--r--quanta/components/debugger/pathmapperdialog.cpp2
-rw-r--r--quanta/components/debugger/pathmapperdialogs.ui6
-rw-r--r--quanta/components/debugger/quantadebuggerinterface.cpp4
-rw-r--r--quanta/components/debugger/quantadebuggerinterface.h2
-rw-r--r--quanta/components/debugger/variableslistview.cpp16
-rw-r--r--quanta/components/framewizard/areaattributedb.h6
-rw-r--r--quanta/components/framewizard/fmfpeditors.ui4
-rw-r--r--quanta/components/framewizard/fmrceditors.ui6
-rw-r--r--quanta/components/framewizard/framewizards.ui12
-rw-r--r--quanta/components/framewizard/selectablearea.cpp2
-rw-r--r--quanta/components/framewizard/treenode.cpp22
-rw-r--r--quanta/components/framewizard/treenode.h24
-rw-r--r--quanta/components/framewizard/visualframeeditor.cpp28
-rw-r--r--quanta/components/framewizard/visualframeeditor.h2
-rw-r--r--quanta/components/tableeditor/tableeditor.cpp24
-rw-r--r--quanta/components/tableeditor/tableeditors.ui14
-rw-r--r--quanta/components/tableeditor/tableitem.cpp6
-rw-r--r--quanta/components/tableeditor/tableitem.h10
55 files changed, 307 insertions, 307 deletions
diff --git a/quanta/components/csseditor/colorrequester.cpp b/quanta/components/csseditor/colorrequester.cpp
index 1e2a1b8b..7538ebe9 100644
--- a/quanta/components/csseditor/colorrequester.cpp
+++ b/quanta/components/csseditor/colorrequester.cpp
@@ -56,7 +56,7 @@ void colorRequester::init()
d->edit = new KLineEdit( this, "line edit" );
myButton = new KPushButton( this, "kfile button");
- TQIconSet iconSet = SmallIconSet(TQString::tqfromLatin1("colorize"));
+ TQIconSet iconSet = SmallIconSet(TQString::fromLatin1("colorize"));
TQPixmap pixMap = iconSet.pixmap( TQIconSet::Small, TQIconSet::Normal );
myButton->setIconSet( iconSet );
myButton->setFixedSize( pixMap.width()+8, pixMap.height()+8 );
diff --git a/quanta/components/csseditor/colorslider.cpp b/quanta/components/csseditor/colorslider.cpp
index 58e67d0f..411f056c 100644
--- a/quanta/components/csseditor/colorslider.cpp
+++ b/quanta/components/csseditor/colorslider.cpp
@@ -37,9 +37,9 @@ colorSlider::colorSlider(const TQString& fn,const TQString& l,const TQString& c,
TQLabel *leftLabel = new TQLabel("<b>" + l +"</b>",leftBox);
TQLabel *centerLabel = new TQLabel(("<b>" + c +"</b>"),centerBox);
TQLabel *rightLabel = new TQLabel(("<b>" + r +"</b>"),rightBox);
- leftLabel->tqsetAlignment(TQt::AlignHCenter);
- centerLabel->tqsetAlignment(TQt::AlignHCenter);
- rightLabel->tqsetAlignment(TQt::AlignHCenter);
+ leftLabel->setAlignment(TQt::AlignHCenter);
+ centerLabel->setAlignment(TQt::AlignHCenter);
+ rightLabel->setAlignment(TQt::AlignHCenter);
leftLabel->setTextFormat (TQt::RichText ) ;
centerLabel->setTextFormat ( TQt::RichText ) ;
rightLabel->setTextFormat (TQt::RichText ) ;
diff --git a/quanta/components/csseditor/csseditor.cpp b/quanta/components/csseditor/csseditor.cpp
index e548d7d9..7f65e9c7 100644
--- a/quanta/components/csseditor/csseditor.cpp
+++ b/quanta/components/csseditor/csseditor.cpp
@@ -16,12 +16,12 @@
***************************************************************************/
#include "csseditor.h"
-#include <tqlayout.h>
+#include <layout.h>
#include <tqtabwidget.h>
#include <tqpushbutton.h>
#include <tqcheckbox.h>
-#include <tqtextedit.h>
-#include <tqtextstream.h>
+#include <textedit.h>
+#include <textstream.h>
#include <tqfileinfo.h>
#include <kapplication.h>
diff --git a/quanta/components/csseditor/csseditors.ui b/quanta/components/csseditor/csseditors.ui
index d1fe0993..2661d75d 100644
--- a/quanta/components/csseditor/csseditors.ui
+++ b/quanta/components/csseditor/csseditors.ui
@@ -32,7 +32,7 @@
<property name="sizeType">
<enum>Expanding</enum>
</property>
- <property name="tqsizeHint">
+ <property name="sizeHint">
<size>
<width>280</width>
<height>20</height>
@@ -41,7 +41,7 @@
</spacer>
<widget class="TQLayoutWidget" row="2" column="2">
<property name="name">
- <cstring>tqlayout6</cstring>
+ <cstring>layout6</cstring>
</property>
<hbox>
<property name="name">
@@ -117,13 +117,13 @@
<verstretch>0</verstretch>
</sizepolicy>
</property>
- <property name="tqminimumSize">
+ <property name="minimumSize">
<size>
<width>33</width>
<height>7</height>
</size>
</property>
- <property name="tqmaximumSize">
+ <property name="maximumSize">
<size>
<width>290</width>
<height>32767</height>
@@ -338,7 +338,7 @@
<verstretch>0</verstretch>
</sizepolicy>
</property>
- <property name="tqminimumSize">
+ <property name="minimumSize">
<size>
<width>0</width>
<height>200</height>
@@ -363,7 +363,7 @@
<verstretch>0</verstretch>
</sizepolicy>
</property>
- <property name="tqmaximumSize">
+ <property name="maximumSize">
<size>
<width>32766</width>
<height>32766</height>
diff --git a/quanta/components/csseditor/cssselector.cpp b/quanta/components/csseditor/cssselector.cpp
index 7e61cf02..cdf9db04 100644
--- a/quanta/components/csseditor/cssselector.cpp
+++ b/quanta/components/csseditor/cssselector.cpp
@@ -21,7 +21,7 @@
#include <tqlineedit.h>
#include <tqcombobox.h>
#include <tqpushbutton.h>
-#include <tqtextstream.h>
+#include <textstream.h>
#include <tqtabwidget.h>
#include <tqobjectlist.h>
#include <tqfileinfo.h>
diff --git a/quanta/components/csseditor/cssselectors.ui b/quanta/components/csseditor/cssselectors.ui
index dd899b1b..cb4ed81b 100644
--- a/quanta/components/csseditor/cssselectors.ui
+++ b/quanta/components/csseditor/cssselectors.ui
@@ -24,7 +24,7 @@
</property>
<widget class="TQLayoutWidget" row="1" column="0" rowspan="1" colspan="3">
<property name="name">
- <cstring>tqlayout11</cstring>
+ <cstring>layout11</cstring>
</property>
<hbox>
<property name="name">
@@ -61,7 +61,7 @@
<property name="sizeType">
<enum>Expanding</enum>
</property>
- <property name="tqsizeHint">
+ <property name="sizeHint">
<size>
<width>20</width>
<height>40</height>
@@ -70,7 +70,7 @@
</spacer>
<widget class="TQLayoutWidget" row="3" column="2">
<property name="name">
- <cstring>tqlayout1</cstring>
+ <cstring>layout1</cstring>
</property>
<hbox>
<property name="name">
@@ -111,7 +111,7 @@
</property>
<widget class="TQLayoutWidget" row="0" column="2">
<property name="name">
- <cstring>tqlayout13</cstring>
+ <cstring>layout13</cstring>
</property>
<vbox>
<property name="name">
@@ -127,7 +127,7 @@
<property name="sizeType">
<enum>Expanding</enum>
</property>
- <property name="tqsizeHint">
+ <property name="sizeHint">
<size>
<width>20</width>
<height>16</height>
@@ -185,7 +185,7 @@
<property name="sizeType">
<enum>Expanding</enum>
</property>
- <property name="tqsizeHint">
+ <property name="sizeHint">
<size>
<width>20</width>
<height>16</height>
@@ -220,7 +220,7 @@
<property name="sizeType">
<enum>Expanding</enum>
</property>
- <property name="tqsizeHint">
+ <property name="sizeHint">
<size>
<width>20</width>
<height>24</height>
@@ -266,7 +266,7 @@
<property name="sizeType">
<enum>Expanding</enum>
</property>
- <property name="tqsizeHint">
+ <property name="sizeHint">
<size>
<width>20</width>
<height>16</height>
@@ -329,7 +329,7 @@
<property name="sizeType">
<enum>Minimum</enum>
</property>
- <property name="tqsizeHint">
+ <property name="sizeHint">
<size>
<width>40</width>
<height>20</height>
@@ -403,7 +403,7 @@
<property name="sizeType">
<enum>Expanding</enum>
</property>
- <property name="tqsizeHint">
+ <property name="sizeHint">
<size>
<width>40</width>
<height>20</height>
@@ -412,7 +412,7 @@
</spacer>
<widget class="TQLayoutWidget" row="0" column="2">
<property name="name">
- <cstring>tqlayout14</cstring>
+ <cstring>layout14</cstring>
</property>
<vbox>
<property name="name">
@@ -428,7 +428,7 @@
<property name="sizeType">
<enum>Expanding</enum>
</property>
- <property name="tqsizeHint">
+ <property name="sizeHint">
<size>
<width>20</width>
<height>40</height>
@@ -478,7 +478,7 @@
<property name="sizeType">
<enum>Expanding</enum>
</property>
- <property name="tqsizeHint">
+ <property name="sizeHint">
<size>
<width>20</width>
<height>40</height>
@@ -521,7 +521,7 @@
<property name="sizeType">
<enum>Expanding</enum>
</property>
- <property name="tqsizeHint">
+ <property name="sizeHint">
<size>
<width>20</width>
<height>40</height>
@@ -597,7 +597,7 @@
<property name="sizeType">
<enum>Expanding</enum>
</property>
- <property name="tqsizeHint">
+ <property name="sizeHint">
<size>
<width>40</width>
<height>20</height>
@@ -606,7 +606,7 @@
</spacer>
<widget class="TQLayoutWidget" row="0" column="2">
<property name="name">
- <cstring>tqlayout13</cstring>
+ <cstring>layout13</cstring>
</property>
<vbox>
<property name="name">
@@ -622,7 +622,7 @@
<property name="sizeType">
<enum>Expanding</enum>
</property>
- <property name="tqsizeHint">
+ <property name="sizeHint">
<size>
<width>20</width>
<height>40</height>
@@ -672,7 +672,7 @@
<property name="sizeType">
<enum>Expanding</enum>
</property>
- <property name="tqsizeHint">
+ <property name="sizeHint">
<size>
<width>20</width>
<height>40</height>
@@ -715,7 +715,7 @@
<property name="sizeType">
<enum>Expanding</enum>
</property>
- <property name="tqsizeHint">
+ <property name="sizeHint">
<size>
<width>20</width>
<height>40</height>
@@ -791,7 +791,7 @@
<property name="sizeType">
<enum>Expanding</enum>
</property>
- <property name="tqsizeHint">
+ <property name="sizeHint">
<size>
<width>40</width>
<height>20</height>
@@ -800,7 +800,7 @@
</spacer>
<widget class="TQLayoutWidget" row="0" column="2">
<property name="name">
- <cstring>tqlayout17</cstring>
+ <cstring>layout17</cstring>
</property>
<vbox>
<property name="name">
@@ -816,7 +816,7 @@
<property name="sizeType">
<enum>Expanding</enum>
</property>
- <property name="tqsizeHint">
+ <property name="sizeHint">
<size>
<width>20</width>
<height>40</height>
@@ -866,7 +866,7 @@
<property name="sizeType">
<enum>Expanding</enum>
</property>
- <property name="tqsizeHint">
+ <property name="sizeHint">
<size>
<width>20</width>
<height>40</height>
@@ -917,7 +917,7 @@
<property name="sizeType">
<enum>Expanding</enum>
</property>
- <property name="tqsizeHint">
+ <property name="sizeHint">
<size>
<width>20</width>
<height>40</height>
@@ -939,7 +939,7 @@
<property name="sizeType">
<enum>Expanding</enum>
</property>
- <property name="tqsizeHint">
+ <property name="sizeHint">
<size>
<width>380</width>
<height>20</height>
diff --git a/quanta/components/csseditor/data/config.xml b/quanta/components/csseditor/data/config.xml
index 988041ca..15fd659f 100644
--- a/quanta/components/csseditor/data/config.xml
+++ b/quanta/components/csseditor/data/config.xml
@@ -469,9 +469,9 @@
<freeedit/>
</right>
- <table-tqlayout>
+ <table-layout>
<list value="auto,fixed,inherit"/>
- </table-tqlayout>
+ </table-layout>
<text-align>
<list value="center,justify,right,left,inherit"/>
@@ -503,9 +503,9 @@
<freeedit/>
</top>
- <tqunicode-bidi>
+ <unicode-bidi>
<list value="normal,embed,bidi-override,inherit"/>
- </tqunicode-bidi>
+ </unicode-bidi>
<vertical-align>
<list value="baseline,inherit,sub,super,top,text-top,middle,bottom,text-bottom"/>
diff --git a/quanta/components/csseditor/encodingselector.cpp b/quanta/components/csseditor/encodingselector.cpp
index f8ba4ac6..4aef2399 100644
--- a/quanta/components/csseditor/encodingselector.cpp
+++ b/quanta/components/csseditor/encodingselector.cpp
@@ -20,7 +20,7 @@
#include "encodingselector.h"
#include <kglobal.h>
#include <kcharsets.h>
-#include <tqtextcodec.h>
+#include <textcodec.h>
/**
*@author gulmini luciano
diff --git a/quanta/components/csseditor/encodingselectors.ui b/quanta/components/csseditor/encodingselectors.ui
index 6ac64343..178eacc4 100644
--- a/quanta/components/csseditor/encodingselectors.ui
+++ b/quanta/components/csseditor/encodingselectors.ui
@@ -21,7 +21,7 @@
</property>
<widget class="TQLayoutWidget" row="0" column="0">
<property name="name">
- <cstring>tqlayout3</cstring>
+ <cstring>layout3</cstring>
</property>
<vbox>
<property name="name">
@@ -29,7 +29,7 @@
</property>
<widget class="TQLayoutWidget">
<property name="name">
- <cstring>tqlayout1</cstring>
+ <cstring>layout1</cstring>
</property>
<hbox>
<property name="name">
@@ -52,7 +52,7 @@
</widget>
<widget class="TQLayoutWidget">
<property name="name">
- <cstring>tqlayout2</cstring>
+ <cstring>layout2</cstring>
</property>
<hbox>
<property name="name">
@@ -76,7 +76,7 @@
<property name="sizeType">
<enum>Expanding</enum>
</property>
- <property name="tqsizeHint">
+ <property name="sizeHint">
<size>
<width>40</width>
<height>20</height>
diff --git a/quanta/components/csseditor/fontfamilychooser.cpp b/quanta/components/csseditor/fontfamilychooser.cpp
index 273c5a4c..bd9e59ef 100644
--- a/quanta/components/csseditor/fontfamilychooser.cpp
+++ b/quanta/components/csseditor/fontfamilychooser.cpp
@@ -36,14 +36,14 @@ fontFamilyChooser::fontFamilyChooser(TQWidget* parent, const char *name) : fontF
TQFont tmpFont( KGlobalSettings::generalFont().family(), 64, TQFont::Black );
lePreview->setMinimumHeight( lePreview->fontMetrics().lineSpacing() );
- lePreview->tqsetAlignment(TQt::AlignCenter);
+ lePreview->setAlignment(TQt::AlignCenter);
TQFont font;
font.setPointSize(20);
lePreview->setFont(font);
lePreview->setText(i18n("The Quick Brown Fox Jumps Over The Lazy Dog"));
TQFontDatabase fdb;
- TQStringList families = fdb.tqfamilies();
+ TQStringList families = fdb.families();
for ( TQStringList::Iterator it = families.begin(); it != families.end(); ++it ) {
if( (*it).contains('[') !=0 )
it = families.remove(it);
@@ -52,20 +52,20 @@ fontFamilyChooser::fontFamilyChooser(TQWidget* parent, const char *name) : fontF
if( families.count() != 0 ) lbAvailable->insertStringList(families);
- TQIconSet iconSet = SmallIconSet(TQString::tqfromLatin1("forward"));
+ TQIconSet iconSet = SmallIconSet(TQString::fromLatin1("forward"));
TQPixmap pixMap = iconSet.pixmap( TQIconSet::Small, TQIconSet::Normal );
pbAdd->setIconSet(iconSet);
pbAdd->setFixedSize( pixMap.width()+8, pixMap.height()+8 );
- iconSet = SmallIconSet(TQString::tqfromLatin1("back"));
+ iconSet = SmallIconSet(TQString::fromLatin1("back"));
pbRemove->setIconSet(iconSet);
pbRemove->setFixedSize( pixMap.width()+8, pixMap.height()+8 );
- iconSet = SmallIconSet(TQString::tqfromLatin1("up"));
+ iconSet = SmallIconSet(TQString::fromLatin1("up"));
pbMoveUp->setIconSet(iconSet);
pbMoveUp->setFixedSize( pixMap.width()+8, pixMap.height()+8 );
- iconSet = SmallIconSet(TQString::tqfromLatin1("down"));
+ iconSet = SmallIconSet(TQString::fromLatin1("down"));
pbMoveDown->setIconSet(iconSet);
pbMoveDown->setFixedSize( pixMap.width()+8, pixMap.height()+8 );
diff --git a/quanta/components/csseditor/fontfamilychoosers.ui b/quanta/components/csseditor/fontfamilychoosers.ui
index 86a109d9..7675741a 100644
--- a/quanta/components/csseditor/fontfamilychoosers.ui
+++ b/quanta/components/csseditor/fontfamilychoosers.ui
@@ -32,7 +32,7 @@
</property>
<widget class="TQLayoutWidget" row="0" column="0">
<property name="name">
- <cstring>tqlayout42</cstring>
+ <cstring>layout42</cstring>
</property>
<vbox>
<property name="name">
@@ -40,7 +40,7 @@
</property>
<widget class="TQLayoutWidget">
<property name="name">
- <cstring>tqlayout40</cstring>
+ <cstring>layout40</cstring>
</property>
<vbox>
<property name="name">
@@ -48,7 +48,7 @@
</property>
<widget class="TQLayoutWidget">
<property name="name">
- <cstring>tqlayout39</cstring>
+ <cstring>layout39</cstring>
</property>
<hbox>
<property name="name">
@@ -56,7 +56,7 @@
</property>
<widget class="TQLayoutWidget">
<property name="name">
- <cstring>tqlayout36</cstring>
+ <cstring>layout36</cstring>
</property>
<vbox>
<property name="name">
@@ -64,7 +64,7 @@
</property>
<widget class="TQLayoutWidget">
<property name="name">
- <cstring>tqlayout20</cstring>
+ <cstring>layout20</cstring>
</property>
<vbox>
<property name="name">
@@ -87,7 +87,7 @@
</widget>
<widget class="TQLayoutWidget">
<property name="name">
- <cstring>tqlayout15</cstring>
+ <cstring>layout15</cstring>
</property>
<vbox>
<property name="name">
@@ -145,7 +145,7 @@
</widget>
<widget class="TQLayoutWidget">
<property name="name">
- <cstring>tqlayout38</cstring>
+ <cstring>layout38</cstring>
</property>
<vbox>
<property name="name">
@@ -164,7 +164,7 @@
<property name="sizeType">
<enum>Expanding</enum>
</property>
- <property name="tqsizeHint">
+ <property name="sizeHint">
<size>
<width>20</width>
<height>40</height>
@@ -193,7 +193,7 @@
<property name="title">
<string></string>
</property>
- <property name="tqalignment">
+ <property name="alignment">
<set>AlignCenter</set>
</property>
<property name="flat">
@@ -219,13 +219,13 @@
<property name="name">
<cstring>pbMoveUp</cstring>
</property>
- <property name="tqminimumSize">
+ <property name="minimumSize">
<size>
<width>22</width>
<height>22</height>
</size>
</property>
- <property name="tqmaximumSize">
+ <property name="maximumSize">
<size>
<width>22</width>
<height>22</height>
@@ -239,13 +239,13 @@
<property name="name">
<cstring>pbAdd</cstring>
</property>
- <property name="tqminimumSize">
+ <property name="minimumSize">
<size>
<width>22</width>
<height>22</height>
</size>
</property>
- <property name="tqmaximumSize">
+ <property name="maximumSize">
<size>
<width>22</width>
<height>22</height>
@@ -259,13 +259,13 @@
<property name="name">
<cstring>pbRemove</cstring>
</property>
- <property name="tqminimumSize">
+ <property name="minimumSize">
<size>
<width>22</width>
<height>22</height>
</size>
</property>
- <property name="tqmaximumSize">
+ <property name="maximumSize">
<size>
<width>22</width>
<height>22</height>
@@ -279,13 +279,13 @@
<property name="name">
<cstring>pbMoveDown</cstring>
</property>
- <property name="tqminimumSize">
+ <property name="minimumSize">
<size>
<width>22</width>
<height>22</height>
</size>
</property>
- <property name="tqmaximumSize">
+ <property name="maximumSize">
<size>
<width>22</width>
<height>22</height>
@@ -307,7 +307,7 @@
<property name="sizeType">
<enum>Expanding</enum>
</property>
- <property name="tqsizeHint">
+ <property name="sizeHint">
<size>
<width>20</width>
<height>40</height>
@@ -318,7 +318,7 @@
</widget>
<widget class="TQLayoutWidget">
<property name="name">
- <cstring>tqlayout6</cstring>
+ <cstring>layout6</cstring>
</property>
<vbox>
<property name="name">
@@ -358,7 +358,7 @@
</widget>
<widget class="TQLayoutWidget">
<property name="name">
- <cstring>tqlayout41</cstring>
+ <cstring>layout41</cstring>
</property>
<hbox>
<property name="name">
@@ -374,7 +374,7 @@
<property name="sizeType">
<enum>Expanding</enum>
</property>
- <property name="tqsizeHint">
+ <property name="sizeHint">
<size>
<width>313</width>
<height>20</height>
@@ -383,7 +383,7 @@
</spacer>
<widget class="TQLayoutWidget">
<property name="name">
- <cstring>tqlayout9</cstring>
+ <cstring>layout9</cstring>
</property>
<hbox>
<property name="name">
diff --git a/quanta/components/csseditor/propertysetter.cpp b/quanta/components/csseditor/propertysetter.cpp
index f1e1c101..922c7dbe 100644
--- a/quanta/components/csseditor/propertysetter.cpp
+++ b/quanta/components/csseditor/propertysetter.cpp
@@ -113,7 +113,7 @@ void propertySetter::addButton(){
m_pb = new KPushButton(this);
TQToolTip::add(m_pb, i18n( "More..." ));
- TQIconSet iconSet = SmallIconSet(TQString::tqfromLatin1("2rightarrow"));
+ TQIconSet iconSet = SmallIconSet(TQString::fromLatin1("2rightarrow"));
TQPixmap pixMap = iconSet.pixmap( TQIconSet::Small, TQIconSet::Normal );
m_pb->setIconSet(iconSet);
m_pb->setFixedSize( pixMap.width()+8, pixMap.height()+8 );
diff --git a/quanta/components/csseditor/styleeditor.cpp b/quanta/components/csseditor/styleeditor.cpp
index b94bdbcd..c62cc7a7 100644
--- a/quanta/components/csseditor/styleeditor.cpp
+++ b/quanta/components/csseditor/styleeditor.cpp
@@ -42,7 +42,7 @@
StyleEditor::StyleEditor(TQWidget *parent, const char* name) : TLPEditor(parent,name){
connect(m_pb, TQT_SIGNAL(clicked()), this, TQT_SLOT(openCSSEditor()));
setToolTip(i18n("Open css dialog"));
- TQIconSet iconSet = SmallIconSet(TQString::tqfromLatin1("stylesheet"));
+ TQIconSet iconSet = SmallIconSet(TQString::fromLatin1("stylesheet"));
TQPixmap pixMap = iconSet.pixmap( TQIconSet::Small, TQIconSet::Normal );
m_pb->setIconSet(iconSet);
m_iconWidth = pixMap.width();
diff --git a/quanta/components/csseditor/stylesheetparser.cpp b/quanta/components/csseditor/stylesheetparser.cpp
index 0a573925..0b80caa2 100644
--- a/quanta/components/csseditor/stylesheetparser.cpp
+++ b/quanta/components/csseditor/stylesheetparser.cpp
@@ -164,11 +164,11 @@ void stylesheetParser::parseSelector(){
if (m_stylesheetStructure.contains(selectorName))
{
uint i = 2;
- TQString s = selectorName + TQString("-v%1").tqarg(i);
+ TQString s = selectorName + TQString("-v%1").arg(i);
while (m_stylesheetStructure.contains(s))
{
i++;
- s = selectorName + TQString("-v%1").tqarg(i);
+ s = selectorName + TQString("-v%1").arg(i);
}
selectorName = s;
}
diff --git a/quanta/components/csseditor/tlpeditors.cpp b/quanta/components/csseditor/tlpeditors.cpp
index 7a35ee23..994876a3 100644
--- a/quanta/components/csseditor/tlpeditors.cpp
+++ b/quanta/components/csseditor/tlpeditors.cpp
@@ -48,7 +48,7 @@ TLPEditor::~TLPEditor(){
}
void TLPEditor::setButtonIcon(TQString s){
- TQIconSet iconSet = SmallIconSet(TQString::tqfromLatin1(s.ascii()));
+ TQIconSet iconSet = SmallIconSet(TQString::fromLatin1(s.ascii()));
TQPixmap pixMap = iconSet.pixmap( TQIconSet::Small, TQIconSet::Normal );
m_pb->setIconSet(iconSet);
m_pb->setFixedSize( pixMap.width()+8, pixMap.height()+8 );
diff --git a/quanta/components/cvsservice/cvscommitdlgs.ui b/quanta/components/cvsservice/cvscommitdlgs.ui
index 3eb19d7a..5f43c131 100644
--- a/quanta/components/cvsservice/cvscommitdlgs.ui
+++ b/quanta/components/cvsservice/cvscommitdlgs.ui
@@ -105,7 +105,7 @@
<property name="sizeType">
<enum>Expanding</enum>
</property>
- <property name="tqsizeHint">
+ <property name="sizeHint">
<size>
<width>80</width>
<height>20</height>
diff --git a/quanta/components/cvsservice/cvsservice.cpp b/quanta/components/cvsservice/cvsservice.cpp
index 930ebeec..9b409b34 100644
--- a/quanta/components/cvsservice/cvsservice.cpp
+++ b/quanta/components/cvsservice/cvsservice.cpp
@@ -17,8 +17,8 @@
#include <tqfile.h>
#include <tqfileinfo.h>
#include <tqradiobutton.h>
-#include <tqtextedit.h>
-#include <tqtextstream.h>
+#include <textedit.h>
+#include <textstream.h>
#include <tqtimer.h>
//kde includes
@@ -176,11 +176,11 @@ void CVSService::slotUpdateToTag(const TQStringList &files)
if (m_updateToDlg->tagRadioButton->isChecked())
{
extraOpts = "-r " + m_updateToDlg->tagCombo->currentText();
- commandStr = i18n("Updating to revision %1 ...").tqarg(m_updateToDlg->tagCombo->currentText());
+ commandStr = i18n("Updating to revision %1 ...").arg(m_updateToDlg->tagCombo->currentText());
} else
{
extraOpts = "-D " + m_updateToDlg->dateLineEdit->text();
- commandStr = i18n("Updating to the version from %1 ...").tqarg(+ m_updateToDlg->dateLineEdit->text());
+ commandStr = i18n("Updating to the version from %1 ...").arg(+ m_updateToDlg->dateLineEdit->text());
}
emit clearMessages();
emit showMessage(commandStr + "\n", false);
@@ -430,7 +430,7 @@ void CVSService::slotAddToCVSIgnore()
line = str.readLine().stripWhiteSpace();
if (line == fInfo.fileName())
{
- emit showMessage(i18n("\"%1\" is already in the CVS ignore list.").tqarg(fInfo.fileName()) + "\n", false);
+ emit showMessage(i18n("\"%1\" is already in the CVS ignore list.").arg(fInfo.fileName()) + "\n", false);
found = true;
break;
}
@@ -438,7 +438,7 @@ void CVSService::slotAddToCVSIgnore()
if (!found)
{
str << fInfo.fileName() << endl;
- emit showMessage(i18n("\"%1\" added to the CVS ignore list.").tqarg(fInfo.fileName()) + "\n", false);
+ emit showMessage(i18n("\"%1\" added to the CVS ignore list.").arg(fInfo.fileName()) + "\n", false);
}
f.close();
}
@@ -477,7 +477,7 @@ void CVSService::slotRemoveFromCVSIgnore()
}
if (!found)
{
- emit showMessage(i18n("\"%1\" is not in the CVS ignore list.").tqarg(fInfo.fileName()) + "\n", false);
+ emit showMessage(i18n("\"%1\" is not in the CVS ignore list.").arg(fInfo.fileName()) + "\n", false);
}
f.close();
}
@@ -486,7 +486,7 @@ void CVSService::slotRemoveFromCVSIgnore()
TQTextStream str(&f);
str.setEncoding(TQTextStream::UnicodeUTF8);
str << content;
- emit showMessage(i18n("\"%1\" removed from the CVS ignore list.").tqarg(fInfo.fileName()) + "\n", false);
+ emit showMessage(i18n("\"%1\" removed from the CVS ignore list.").arg(fInfo.fileName()) + "\n", false);
f.close();
}
@@ -501,7 +501,7 @@ void CVSService::slotJobExited(bool normalExit, int exitStatus)
{
if (!normalExit)
{
- KMessageBox::sorry(0, i18n("<qt>The CVS command <b>%1</b> has failed. The error code was <i>%2</i>.</qt>").tqarg(m_cvsCommand).tqarg(exitStatus), i18n("Command Failed"));
+ KMessageBox::sorry(0, i18n("<qt>The CVS command <b>%1</b> has failed. The error code was <i>%2</i>.</qt>").arg(m_cvsCommand).arg(exitStatus), i18n("Command Failed"));
}
if (exitStatus == 0)
{
@@ -529,7 +529,7 @@ void CVSService::slotReceivedStderr(TQString output)
void CVSService::notInRepository()
{
emit clearMessages();
- emit showMessage(i18n("Error: \"%1\" is not part of the\n\"%2\" repository.").tqarg(m_defaultFile).tqarg(m_repositoryPath) + "\n", false);
+ emit showMessage(i18n("Error: \"%1\" is not part of the\n\"%2\" repository.").arg(m_defaultFile).arg(m_repositoryPath) + "\n", false);
}
void CVSService::startService()
diff --git a/quanta/components/cvsservice/cvsupdatetodlgs.ui b/quanta/components/cvsservice/cvsupdatetodlgs.ui
index 4b85c5d2..d4d2dc7b 100644
--- a/quanta/components/cvsservice/cvsupdatetodlgs.ui
+++ b/quanta/components/cvsservice/cvsupdatetodlgs.ui
@@ -82,7 +82,7 @@
<property name="sizeType">
<enum>Fixed</enum>
</property>
- <property name="tqsizeHint">
+ <property name="sizeHint">
<size>
<width>40</width>
<height>20</height>
@@ -104,7 +104,7 @@
<property name="sizeType">
<enum>Fixed</enum>
</property>
- <property name="tqsizeHint">
+ <property name="sizeHint">
<size>
<width>40</width>
<height>20</height>
@@ -115,7 +115,7 @@
</widget>
<widget class="TQLayoutWidget" row="1" column="0">
<property name="name">
- <cstring>tqlayout5</cstring>
+ <cstring>layout5</cstring>
</property>
<grid>
<property name="name">
@@ -147,7 +147,7 @@
<property name="sizeType">
<enum>Expanding</enum>
</property>
- <property name="tqsizeHint">
+ <property name="sizeHint">
<size>
<width>295</width>
<height>20</height>
diff --git a/quanta/components/debugger/conditionalbreakpointdialogs.ui b/quanta/components/debugger/conditionalbreakpointdialogs.ui
index dd94f4ae..fcd4b1db 100644
--- a/quanta/components/debugger/conditionalbreakpointdialogs.ui
+++ b/quanta/components/debugger/conditionalbreakpointdialogs.ui
@@ -62,7 +62,7 @@
<property name="sizeType">
<enum>Expanding</enum>
</property>
- <property name="tqsizeHint">
+ <property name="sizeHint">
<size>
<width>20</width>
<height>20</height>
@@ -144,7 +144,7 @@
<property name="sizeType">
<enum>Expanding</enum>
</property>
- <property name="tqsizeHint">
+ <property name="sizeHint">
<size>
<width>30</width>
<height>20</height>
@@ -163,13 +163,13 @@
<property name="name">
<cstring>ledWarning</cstring>
</property>
- <property name="tqminimumSize">
+ <property name="minimumSize">
<size>
<width>22</width>
<height>22</height>
</size>
</property>
- <property name="tqmaximumSize">
+ <property name="maximumSize">
<size>
<width>22</width>
<height>22</height>
@@ -215,7 +215,7 @@
<property name="text">
<string>File:</string>
</property>
- <property name="tqalignment">
+ <property name="alignment">
<set>AlignVCenter</set>
</property>
</widget>
@@ -234,7 +234,7 @@
<property name="text">
<string>Objects of class:</string>
</property>
- <property name="tqalignment">
+ <property name="alignment">
<set>AlignVCenter</set>
</property>
</widget>
@@ -253,7 +253,7 @@
<property name="text">
<string>Function:</string>
</property>
- <property name="tqalignment">
+ <property name="alignment">
<set>AlignVCenter</set>
</property>
</widget>
diff --git a/quanta/components/debugger/dbgp/dbgpnetwork.cpp b/quanta/components/debugger/dbgp/dbgpnetwork.cpp
index 584e71f0..a087ae03 100644
--- a/quanta/components/debugger/dbgp/dbgpnetwork.cpp
+++ b/quanta/components/debugger/dbgp/dbgpnetwork.cpp
@@ -71,14 +71,14 @@ void DBGpNetwork::sessionStart(bool useproxy, const TQString& server, const TQSt
if(m_server->listen())
{
emit active(true);
- emit networkError(i18n("Listening on port %1").tqarg(service), true);
+ emit networkError(i18n("Listening on port %1").arg(service), true);
}
else
{
delete m_server;
m_server = NULL;
emit active(false);
- emit networkError(i18n("Unable to listen on port %1").tqarg(service), true);
+ emit networkError(i18n("Unable to listen on port %1").arg(service), true);
}
}
}
@@ -293,7 +293,7 @@ long DBGpNetwork::sendCommand(const TQString & command, const TQString & argumen
return false;
m_transaction_id++;
- TQString commandline = command + TQString(" -i %1").tqarg(m_transaction_id) + (!arguments.isEmpty() ? " " : "") + arguments;
+ TQString commandline = command + TQString(" -i %1").arg(m_transaction_id) + (!arguments.isEmpty() ? " " : "") + arguments;
kdDebug(24002) << k_funcinfo << ", sending: " << commandline << endl;
diff --git a/quanta/components/debugger/dbgp/dbgpsettingss.ui b/quanta/components/debugger/dbgp/dbgpsettingss.ui
index b8ab40bd..10888885 100644
--- a/quanta/components/debugger/dbgp/dbgpsettingss.ui
+++ b/quanta/components/debugger/dbgp/dbgpsettingss.ui
@@ -46,7 +46,7 @@
<property name="sizeType">
<enum>Expanding</enum>
</property>
- <property name="tqsizeHint">
+ <property name="sizeHint">
<size>
<width>20</width>
<height>20</height>
@@ -207,7 +207,7 @@
<property name="sizeType">
<enum>Expanding</enum>
</property>
- <property name="tqsizeHint">
+ <property name="sizeHint">
<size>
<width>21</width>
<height>40</height>
@@ -496,7 +496,7 @@
<property name="text">
<string>Break on:</string>
</property>
- <property name="tqalignment">
+ <property name="alignment">
<set>AlignTop</set>
</property>
</widget>
@@ -605,7 +605,7 @@
<property name="text">
<string>Default mode:</string>
</property>
- <property name="tqalignment">
+ <property name="alignment">
<set>AlignVCenter</set>
</property>
</widget>
@@ -621,7 +621,7 @@
<property name="sizeType">
<enum>Expanding</enum>
</property>
- <property name="tqsizeHint">
+ <property name="sizeHint">
<size>
<width>21</width>
<height>40</height>
diff --git a/quanta/components/debugger/dbgp/qbytearrayfifo.cpp b/quanta/components/debugger/dbgp/qbytearrayfifo.cpp
index 578fedb9..7c76066b 100644
--- a/quanta/components/debugger/dbgp/qbytearrayfifo.cpp
+++ b/quanta/components/debugger/dbgp/qbytearrayfifo.cpp
@@ -47,7 +47,7 @@ TQString TQByteArrayFifo::retrieve( )
bool TQByteArrayFifo::append(const char * chars, size_t size )
{
// Resize the array, fail if not possible
- if(!m_array.tqresize(m_size + size ))
+ if(!m_array.resize(m_size + size ))
return false;
// Copy the elements
diff --git a/quanta/components/debugger/dbgp/quantadebuggerdbgp.cpp b/quanta/components/debugger/dbgp/quantadebuggerdbgp.cpp
index 4ee2bceb..3fe2f972 100644
--- a/quanta/components/debugger/dbgp/quantadebuggerdbgp.cpp
+++ b/quanta/components/debugger/dbgp/quantadebuggerdbgp.cpp
@@ -57,7 +57,7 @@ QuantaDebuggerDBGp::QuantaDebuggerDBGp (TQObject *parent, const char*, const TQS
m_supportsasync = false;
m_defaultExecutionState = Starting;
setExecutionState(m_defaultExecutionState);
- emit updatetqStatus(DebuggerUI::NoSession);
+ emit updateStatus(DebuggerUI::NoSession);
connect(&m_network, TQT_SIGNAL(command(const TQString&)), this, TQT_SLOT(processCommand(const TQString&)));
connect(&m_network, TQT_SIGNAL(active(bool)), this, TQT_SLOT(slotNetworkActive(bool)));
@@ -88,9 +88,9 @@ void QuantaDebuggerDBGp::slotNetworkActive(bool active)
setExecutionState(m_defaultExecutionState);
if(active)
- emit updatetqStatus(DebuggerUI::AwaitingConnection);
+ emit updateStatus(DebuggerUI::AwaitingConnection);
else
- emit updatetqStatus(DebuggerUI::NoSession);
+ emit updateStatus(DebuggerUI::NoSession);
}
@@ -113,11 +113,11 @@ void QuantaDebuggerDBGp::slotNetworkConnected(bool connected)
debuggerInterface()->setActiveLine("", 0);
if(connected)
- emit updatetqStatus(DebuggerUI::Connected);
+ emit updateStatus(DebuggerUI::Connected);
else
{
setExecutionState(m_defaultExecutionState);
- emit updatetqStatus(DebuggerUI::AwaitingConnection);
+ emit updateStatus(DebuggerUI::AwaitingConnection);
profilerOpen(false);
}
@@ -126,7 +126,7 @@ void QuantaDebuggerDBGp::slotNetworkConnected(bool connected)
void QuantaDebuggerDBGp::slotNetworkError(const TQString &errormsg, bool log)
{
- debuggerInterface()->showtqStatus(errormsg, log);
+ debuggerInterface()->showStatus(errormsg, log);
}
@@ -194,29 +194,29 @@ void QuantaDebuggerDBGp::setExecutionState(const TQString &state)
if(state == "starting")
{
setExecutionState(Starting);
- emit updatetqStatus(DebuggerUI::Paused);
+ emit updateStatus(DebuggerUI::Paused);
}
else if(state == "stopping")
{
setExecutionState(Stopping);
- emit updatetqStatus(DebuggerUI::Paused);
+ emit updateStatus(DebuggerUI::Paused);
m_network.slotSocketDestroyed(); //XDebug disconnects when stopped and destroys our socket
}
else if(state == "stopped")
{
setExecutionState(Stopped);
- emit updatetqStatus(DebuggerUI::Paused);
+ emit updateStatus(DebuggerUI::Paused);
m_network.slotSocketDestroyed(); //XDebug disconnects when stopped and destroys our socket
}
else if(state == "running")
{
setExecutionState(Running);
- emit updatetqStatus(DebuggerUI::Running);
+ emit updateStatus(DebuggerUI::Running);
}
else if(state == "break")
{
setExecutionState(Break);
- emit updatetqStatus(DebuggerUI::Paused);
+ emit updateStatus(DebuggerUI::Paused);
}
}
@@ -263,7 +263,7 @@ void QuantaDebuggerDBGp::processCommand(const TQString& datas)
TQDomNode response = data.elementsByTagName("response").item(0);
TQString command = attribute(response, "command");
- // tqStatus command
+ // Status command
if(command == "status")
setExecutionState(attribute(response, "status"));
@@ -327,7 +327,7 @@ void QuantaDebuggerDBGp::processCommand(const TQString& datas)
}
else
{
- debuggerInterface()->showtqStatus(i18n("Unrecognized package: '%1%2'").tqarg(datas.left(50)).tqarg(datas.length() > 50 ? "..." : ""), true);
+ debuggerInterface()->showStatus(i18n("Unrecognized package: '%1%2'").arg(datas.left(50)).arg(datas.length() > 50 ? "..." : ""), true);
kdDebug(24002) << datas << endl;
}
@@ -338,10 +338,10 @@ void QuantaDebuggerDBGp::initiateSession(const TQDomNode& initpacket)
{
if(attribute(initpacket, "protocol_version") != protocolversion)
{
- debuggerInterface()->showtqStatus(
+ debuggerInterface()->showStatus(
i18n("The debugger for %1 uses an unsupported protocol version (%2)")
- .tqarg(attribute(initpacket, "language"))
- .tqarg(attribute(initpacket, "protocol_version"))
+ .arg(attribute(initpacket, "language"))
+ .arg(attribute(initpacket, "protocol_version"))
, true);
endSession();
@@ -540,7 +540,7 @@ void QuantaDebuggerDBGp::addBreakpoint (DebuggerBreakpoint* breakpoint)
" -n " + TQString::number(breakpoint->line() + 1)
, breakpoint->condition());
- breakpoint->setKey(TQString("id %1").tqarg(id));
+ breakpoint->setKey(TQString("id %1").arg(id));
}
void QuantaDebuggerDBGp::setBreakpointKey( const TQDomNode & response )
@@ -550,7 +550,7 @@ void QuantaDebuggerDBGp::setBreakpointKey( const TQDomNode & response )
id = attribute(response, "transaction_id").toLong();
if(id > 0)
{
- TQString oldkey = TQString("id %1").tqarg(id);
+ TQString oldkey = TQString("id %1").arg(id);
DebuggerBreakpoint *bp = debuggerInterface()->findDebuggerBreakpoint(oldkey);
if(bp)
debuggerInterface()->updateBreakpointKey(*bp, attribute(response, "id"));
@@ -867,9 +867,9 @@ void QuantaDebuggerDBGp::profilerOpen(bool forceopen)
else
{
if(forceopen)
- KMessageBox::sorry(NULL, i18n("Unable to open profiler output (%1)").tqarg(profileroutput), i18n("Profiler File Error"));
+ KMessageBox::sorry(NULL, i18n("Unable to open profiler output (%1)").arg(profileroutput), i18n("Profiler File Error"));
else
- debuggerInterface()->showtqStatus(i18n("Unable to open profiler output (%1)").tqarg(profileroutput), false);
+ debuggerInterface()->showStatus(i18n("Unable to open profiler output (%1)").arg(profileroutput), false);
}
}
else
@@ -923,7 +923,7 @@ void QuantaDebuggerDBGp::propertySetResponse( const TQDomNode & setnode)
{
if(attribute(setnode, "success") == "0")
{
- debuggerInterface()->showtqStatus(i18n("Unable to set value of variable."), true);
+ debuggerInterface()->showStatus(i18n("Unable to set value of variable."), true);
}
}
@@ -932,11 +932,11 @@ DebuggerVariable* QuantaDebuggerDBGp::buildVariable( const TQDomNode & variablen
{
/*
Sample:
- <property name="$arrayVar" fullname="$arrayVar" address="-1073754976" type="hash" tqchildren="1" numtqchildren="4">
+ <property name="$arrayVar" fullname="$arrayVar" address="-1073754976" type="hash" children="1" numchildren="4">
<property name="birthyear" fullname="$arrayVar['birthyear']" address="135522364" type="int">
<![CDATA[1949]]>
</property>
- <property name="songs" fullname="$arrayVar['songs']" address="135522236" type="hash" tqchildren="1" numtqchildren="3">
+ <property name="songs" fullname="$arrayVar['songs']" address="135522236" type="hash" children="1" numchildren="3">
<property name="0" fullname="$arrayVar['songs'][0]" address="135522332" type="string" encoding="base64">
<![CDATA[SW5ub2NlbnQgV2hlbiBZb3UgRHJlYW0=]]>
</property>
@@ -1021,16 +1021,16 @@ void QuantaDebuggerDBGp::handleError(const TQDomNode & statusnode )
}
else
{
- emit updatetqStatus(DebuggerUI::HaltedOnError);
- debuggerInterface()->showtqStatus(errornode.firstChild().nodeValue(), true);
+ emit updateStatus(DebuggerUI::HaltedOnError);
+ debuggerInterface()->showStatus(errornode.firstChild().nodeValue(), true);
}
break;
}
else
{
// Fatal error
- emit updatetqStatus(DebuggerUI::HaltedOnError);
- debuggerInterface()->showtqStatus(errornode.firstChild().nodeValue(), true);
+ emit updateStatus(DebuggerUI::HaltedOnError);
+ debuggerInterface()->showStatus(errornode.firstChild().nodeValue(), true);
}
}
errornode = errornode.nextSibling();
diff --git a/quanta/components/debugger/dbgp/quantadebuggerdbgp.h b/quanta/components/debugger/dbgp/quantadebuggerdbgp.h
index 8e5b667f..668fbe30 100644
--- a/quanta/components/debugger/dbgp/quantadebuggerdbgp.h
+++ b/quanta/components/debugger/dbgp/quantadebuggerdbgp.h
@@ -161,7 +161,7 @@ class QuantaDebuggerDBGp : public DebuggerClient
void processCommand(const TQString&);
signals:
- void updatetqStatus(DebuggerUI::DebuggertqStatus);
+ void updateStatus(DebuggerUI::DebuggerStatus);
};
#endif
diff --git a/quanta/components/debugger/debuggermanager.cpp b/quanta/components/debugger/debuggermanager.cpp
index 0e65ee5c..fa8f9719 100644
--- a/quanta/components/debugger/debuggermanager.cpp
+++ b/quanta/components/debugger/debuggermanager.cpp
@@ -67,7 +67,7 @@ void DebuggerManager::slotNewProjectLoaded(const TQString &projectname, const KU
if(m_client)
{
- disconnect(m_client, TQT_SIGNAL(updatetqStatus(DebuggerUI::DebuggertqStatus)), m_debuggerui, TQT_SLOT(slottqStatus(DebuggerUI::DebuggertqStatus)));
+ disconnect(m_client, TQT_SIGNAL(updateStatus(DebuggerUI::DebuggerStatus)), m_debuggerui, TQT_SLOT(slotStatus(DebuggerUI::DebuggerStatus)));
delete m_client;
m_client = NULL;
@@ -108,7 +108,7 @@ void DebuggerManager::slotNewProjectLoaded(const TQString &projectname, const KU
if(!m_client)
{
emit hideSplash();
- KMessageBox::error(NULL, i18n("<qt>Unable to load the debugger plugin, error code %1 was returned: <b>%2</b>.</qt>").tqarg(errCode).tqarg(KLibLoader::self()->lastErrorMessage()), i18n("Debugger Error"));
+ KMessageBox::error(NULL, i18n("<qt>Unable to load the debugger plugin, error code %1 was returned: <b>%2</b>.</qt>").arg(errCode).arg(KLibLoader::self()->lastErrorMessage()), i18n("Debugger Error"));
}
break;
}
@@ -143,7 +143,7 @@ void DebuggerManager::slotNewProjectLoaded(const TQString &projectname, const KU
// recreate UI
m_debuggerui = new DebuggerUI(this, "debuggerui");
- connect(m_client, TQT_SIGNAL(updatetqStatus(DebuggerUI::DebuggertqStatus)), m_debuggerui, TQT_SLOT(slottqStatus(DebuggerUI::DebuggertqStatus)));
+ connect(m_client, TQT_SIGNAL(updateStatus(DebuggerUI::DebuggerStatus)), m_debuggerui, TQT_SLOT(slotStatus(DebuggerUI::DebuggerStatus)));
// Load saved breakpoints
if(Project::ref()->debuggerPersistentBreakpoints())
@@ -299,7 +299,7 @@ DebuggerManager::~DebuggerManager()
if(m_client)
{
- disconnect(m_client, TQT_SIGNAL(updatetqStatus(DebuggerUI::DebuggertqStatus)), m_debuggerui, TQT_SLOT(slottqStatus(DebuggerUI::DebuggertqStatus)));
+ disconnect(m_client, TQT_SIGNAL(updateStatus(DebuggerUI::DebuggerStatus)), m_debuggerui, TQT_SLOT(slotStatus(DebuggerUI::DebuggerStatus)));
delete m_client;
m_client = 0L;
@@ -605,7 +605,7 @@ bool DebuggerManager::setActiveLine (const TQString& file, int line )
quantaApp->gotoFileAndLine(filename, line, 0);
else
{
- showtqStatus(i18n("Unable to open file %1, check your basedirs and mappings.").tqarg(filename), true);
+ showStatus(i18n("Unable to open file %1, check your basedirs and mappings.").arg(filename), true);
}
// Add new active line mark
@@ -659,7 +659,7 @@ void DebuggerManager::disconnectBreakpointSignals(Document* qdoc)
}
// Show a status message and optionally put it on the log
-bool DebuggerManager::showtqStatus(const TQString& a_message, bool log)
+bool DebuggerManager::showStatus(const TQString& a_message, bool log)
{
TQString message = a_message;
quantaApp->slotStatusMsg(m_client->getName() + ": " + message);
diff --git a/quanta/components/debugger/debuggermanager.h b/quanta/components/debugger/debuggermanager.h
index 8fae5864..de032937 100644
--- a/quanta/components/debugger/debuggermanager.h
+++ b/quanta/components/debugger/debuggermanager.h
@@ -71,7 +71,7 @@ class DebuggerManager : public TQObject
void updateBreakpointKey(const DebuggerBreakpoint &bp, const TQString& newkey);
// Public help functions
- bool showtqStatus(const TQString& message, bool log);
+ bool showStatus(const TQString& message, bool log);
bool setActiveLine (const TQString& file, int line);
void setMark(const TQString& filename, long line, bool set, int mark);
diff --git a/quanta/components/debugger/debuggerui.cpp b/quanta/components/debugger/debuggerui.cpp
index d2f710b6..fdf32a5c 100644
--- a/quanta/components/debugger/debuggerui.cpp
+++ b/quanta/components/debugger/debuggerui.cpp
@@ -109,7 +109,7 @@ void DebuggerUI::showMenu()
else
m_debuggerMenuID = 0;
- // tqStatus indicator
+ // Status indicator
quantaApp->statusBar()->insertFixedItem(i18n("Debugger Inactive"), IDS_STATUS_DEBUGGER);
}
@@ -124,7 +124,7 @@ void DebuggerUI::hideMenu()
}
m_debuggerMenuID = 0;
- // tqStatus indicator
+ // Status indicator
quantaApp->statusBar()->removeItem(IDS_STATUS_DEBUGGER);
}
@@ -148,7 +148,7 @@ void DebuggerUI::sendRequest(const KURL &url)
m_preview->openURL(url);
}
-void DebuggerUI::slottqStatus( DebuggertqStatus status )
+void DebuggerUI::slotStatus( DebuggerStatus status )
{
switch(status)
{
diff --git a/quanta/components/debugger/debuggerui.h b/quanta/components/debugger/debuggerui.h
index de939315..c7e7d145 100644
--- a/quanta/components/debugger/debuggerui.h
+++ b/quanta/components/debugger/debuggerui.h
@@ -38,7 +38,7 @@ class DebuggerUI : public TQObject
TQ_OBJECT
public:
- enum DebuggertqStatus
+ enum DebuggerStatus
{
NoSession = 0,
AwaitingConnection,
@@ -83,8 +83,8 @@ class DebuggerUI : public TQObject
WHTMLPart *m_preview;
public slots:
- // tqStatus indication
- void slottqStatus(DebuggerUI::DebuggertqStatus status);
+ // Status indication
+ void slotStatus(DebuggerUI::DebuggerStatus status);
};
diff --git a/quanta/components/debugger/debuggervariable.cpp b/quanta/components/debugger/debuggervariable.cpp
index 46f827cb..390290a7 100644
--- a/quanta/components/debugger/debuggervariable.cpp
+++ b/quanta/components/debugger/debuggervariable.cpp
@@ -258,17 +258,17 @@ DebuggerVariable* DebuggerVariable::findItem( TQListViewItem * item, bool traver
return NULL;
}
-void DebuggerVariable::copy( DebuggerVariable * v, bool copytqchildren )
+void DebuggerVariable::copy( DebuggerVariable * v, bool copychildren )
{
m_name = v->name();
- m_size = (v->isScalar() || copytqchildren ? v->size() : m_valueList.count());
+ m_size = (v->isScalar() || copychildren ? v->size() : m_valueList.count());
m_value = v->value();
m_type = v->type();
m_isReference = v->isReference();
// We cant just assign m_valuelist to v->values(), it would make a shallow copy...
//
- if(copytqchildren)
+ if(copychildren)
{
m_valueList.clear();
for(DebuggerVariable * v2 = v->values().first(); v2; v2 = v->values().next())
diff --git a/quanta/components/debugger/debuggervariablesets.ui b/quanta/components/debugger/debuggervariablesets.ui
index 09a3873c..f8d674d5 100644
--- a/quanta/components/debugger/debuggervariablesets.ui
+++ b/quanta/components/debugger/debuggervariablesets.ui
@@ -46,7 +46,7 @@
<property name="sizeType">
<enum>Expanding</enum>
</property>
- <property name="tqsizeHint">
+ <property name="sizeHint">
<size>
<width>20</width>
<height>20</height>
@@ -125,7 +125,7 @@
<property name="text">
<string>New value:</string>
</property>
- <property name="tqalignment">
+ <property name="alignment">
<set>AlignTop</set>
</property>
</widget>
@@ -139,7 +139,7 @@
<property name="sizeType">
<enum>Expanding</enum>
</property>
- <property name="tqsizeHint">
+ <property name="sizeHint">
<size>
<width>30</width>
<height>20</height>
diff --git a/quanta/components/debugger/gubed/gubedsettingss.ui b/quanta/components/debugger/gubed/gubedsettingss.ui
index ccca567c..c9caa54c 100644
--- a/quanta/components/debugger/gubed/gubedsettingss.ui
+++ b/quanta/components/debugger/gubed/gubedsettingss.ui
@@ -46,7 +46,7 @@
<property name="sizeType">
<enum>Expanding</enum>
</property>
- <property name="tqsizeHint">
+ <property name="sizeHint">
<size>
<width>20</width>
<height>20</height>
@@ -116,7 +116,7 @@
<property name="sizeType">
<enum>Expanding</enum>
</property>
- <property name="tqsizeHint">
+ <property name="sizeHint">
<size>
<width>21</width>
<height>40</height>
@@ -407,7 +407,7 @@
<property name="text">
<string>Break on:</string>
</property>
- <property name="tqalignment">
+ <property name="alignment">
<set>AlignTop</set>
</property>
</widget>
@@ -487,7 +487,7 @@
<property name="sizeType">
<enum>Expanding</enum>
</property>
- <property name="tqsizeHint">
+ <property name="sizeHint">
<size>
<width>21</width>
<height>50</height>
@@ -530,7 +530,7 @@
<property name="name">
<cstring>sliderDisplayDelay</cstring>
</property>
- <property name="tqminimumSize">
+ <property name="minimumSize">
<size>
<width>0</width>
<height>27</height>
@@ -566,7 +566,7 @@
<property name="text">
<string>Slow</string>
</property>
- <property name="tqalignment">
+ <property name="alignment">
<set>AlignVCenter|AlignRight</set>
</property>
</widget>
@@ -606,7 +606,7 @@
<property name="text">
<string>Default mode:</string>
</property>
- <property name="tqalignment">
+ <property name="alignment">
<set>AlignVCenter</set>
</property>
</widget>
@@ -617,7 +617,7 @@
<property name="text">
<string>Run speed:</string>
</property>
- <property name="tqalignment">
+ <property name="alignment">
<set>AlignVCenter</set>
</property>
</widget>
@@ -670,7 +670,7 @@
<property name="scaledContents">
<bool>false</bool>
</property>
- <property name="tqalignment">
+ <property name="alignment">
<set>AlignCenter</set>
</property>
</widget>
diff --git a/quanta/components/debugger/gubed/quantadebuggergubed.cpp b/quanta/components/debugger/gubed/quantadebuggergubed.cpp
index d083739a..3edcd527 100644
--- a/quanta/components/debugger/gubed/quantadebuggergubed.cpp
+++ b/quanta/components/debugger/gubed/quantadebuggergubed.cpp
@@ -57,7 +57,7 @@ QuantaDebuggerGubed::QuantaDebuggerGubed (TQObject *parent, const char* name, co
m_defaultExecutionState = Pause;
setExecutionState(m_defaultExecutionState);
- emit updatetqStatus(DebuggerUI::NoSession);
+ emit updateStatus(DebuggerUI::NoSession);
m_datalen = -1;
}
@@ -80,7 +80,7 @@ QuantaDebuggerGubed::~QuantaDebuggerGubed ()
delete m_server;
m_server = NULL;
}
- emit updatetqStatus(DebuggerUI::NoSession);
+ emit updateStatus(DebuggerUI::NoSession);
}
// Try to make a connection to the gubed server
@@ -109,7 +109,7 @@ void QuantaDebuggerGubed::startSession()
debuggerInterface()->enableAction("debug_request", false);
kdDebug(24002) << k_funcinfo << ", proxy:" << m_serverHost << ", " << m_serverPort.toUInt() << endl;
- emit updatetqStatus(DebuggerUI::AwaitingConnection);
+ emit updateStatus(DebuggerUI::AwaitingConnection);
}
}
else
@@ -123,14 +123,14 @@ void QuantaDebuggerGubed::startSession()
if(m_server->listen())
{
- emit updatetqStatus(DebuggerUI::AwaitingConnection);
+ emit updateStatus(DebuggerUI::AwaitingConnection);
debuggerInterface()->enableAction("debug_connect", false);
debuggerInterface()->enableAction("debug_disconnect", true);
debuggerInterface()->enableAction("debug_request", true);
}
else
{
- emit updatetqStatus(DebuggerUI::NoSession);
+ emit updateStatus(DebuggerUI::NoSession);
delete m_server;
m_server = NULL;
debuggerInterface()->enableAction("debug_connect", true);
@@ -174,7 +174,7 @@ void QuantaDebuggerGubed::endSession()
debuggerInterface()->enableAction("debug_leap", false);
debuggerInterface()->enableAction("debug_pause", false);
- emit updatetqStatus(DebuggerUI::NoSession);
+ emit updateStatus(DebuggerUI::NoSession);
}
// Change executionstate of the script
@@ -185,7 +185,7 @@ void QuantaDebuggerGubed::setExecutionState(State newstate)
sendCommand("pause", (char*)0L);
sendCommand("sendactiveline", (char*)0L);
if(isActive())
- emit updatetqStatus(DebuggerUI::Paused);
+ emit updateStatus(DebuggerUI::Paused);
}
else if(newstate == Run)
{
@@ -194,7 +194,7 @@ void QuantaDebuggerGubed::setExecutionState(State newstate)
sendCommand("run", (char*)0L);
if(isActive())
- emit updatetqStatus(DebuggerUI::Running);
+ emit updateStatus(DebuggerUI::Running);
}
else if(newstate == Trace)
{
@@ -203,7 +203,7 @@ void QuantaDebuggerGubed::setExecutionState(State newstate)
sendCommand("trace", (char*)0L);
if(isActive())
- emit updatetqStatus(DebuggerUI::Tracing);
+ emit updateStatus(DebuggerUI::Tracing);
}
m_executionState = newstate;
@@ -259,14 +259,14 @@ void QuantaDebuggerGubed::slotError(int)
if(m_socket->error())
{
kdDebug(24002) << k_funcinfo << ", " << m_socket->KSocketBase::errorString() << endl;
- debuggerInterface()->showtqStatus(m_socket->KSocketBase::errorString(), false);
+ debuggerInterface()->showStatus(m_socket->KSocketBase::errorString(), false);
}
}
if(m_server && m_server->error())
{
kdDebug(24002) << k_funcinfo << ", " << m_server->errorString() << endl;
- debuggerInterface()->showtqStatus(m_server->errorString(), false);
+ debuggerInterface()->showStatus(m_server->errorString(), false);
}
}
@@ -294,7 +294,7 @@ void QuantaDebuggerGubed::slotReadyAccept()
connect(m_socket, TQT_SIGNAL(readyRead()), this, TQT_SLOT(slotReadyRead()));
connected();
- emit updatetqStatus(DebuggerUI::Connected);
+ emit updateStatus(DebuggerUI::Connected);
}
else
{
@@ -307,7 +307,7 @@ void QuantaDebuggerGubed::slotReadyAccept()
// Connection established
void QuantaDebuggerGubed::slotConnected(const KNetwork::KResolverEntry &)
{
- emit updatetqStatus(DebuggerUI::Connected);
+ emit updateStatus(DebuggerUI::Connected);
connected();
}
@@ -353,7 +353,7 @@ void QuantaDebuggerGubed::slotConnectionClosed()
debuggerInterface()->setActiveLine("", 0);
- emit updatetqStatus(DebuggerUI::AwaitingConnection);
+ emit updateStatus(DebuggerUI::AwaitingConnection);
m_active = false;
}
@@ -445,9 +445,9 @@ void QuantaDebuggerGubed::processCommand(const TQString& datas)
long argcnt = args["args"].toLong();
TQString msg = i18n(args["message"].ascii()); // How will we get these messages throught to the translators?
for(int cnt = 1; cnt <= argcnt; cnt++)
- msg.replace("%" + TQString("%1").tqarg(cnt) + "%", args[TQString("arg%1").tqarg(cnt)]);
+ msg.replace("%" + TQString("%1").arg(cnt) + "%", args[TQString("arg%1").arg(cnt)]);
- debuggerInterface()->showtqStatus(msg, false);
+ debuggerInterface()->showStatus(msg, false);
}
// New current line
else if(m_command == "setactiveline")
@@ -462,7 +462,7 @@ void QuantaDebuggerGubed::processCommand(const TQString& datas)
// Parsing failed
else if(m_command == "parsefailed")
{
- debuggerInterface()->showtqStatus(i18n("Syntax or parse error in %1)").tqarg(args["filenme"]), true);
+ debuggerInterface()->showStatus(i18n("Syntax or parse error in %1)").arg(args["filenme"]), true);
return;
}
// A debugging session is running
@@ -479,7 +479,7 @@ void QuantaDebuggerGubed::processCommand(const TQString& datas)
else if(m_command == "error")
{
// Put the line number first so double clicking will jump to the corrrect line
- debuggerInterface()->showtqStatus(i18n("Error occurred: Line %1, Code %2 (%3) in %4").tqarg(args["line"]).tqarg(args["errnum"]).tqarg(args["errmsg"]).tqarg(args["filename"]), true);
+ debuggerInterface()->showStatus(i18n("Error occurred: Line %1, Code %2 (%3) in %4").arg(args["line"]).arg(args["errnum"]).arg(args["errmsg"]).arg(args["filename"]), true);
// Filter to get error code only and match it with out mask
long error = args["errnum"].toLong();
@@ -492,21 +492,21 @@ void QuantaDebuggerGubed::processCommand(const TQString& datas)
else
setExecutionState(Pause);
- emit updatetqStatus(DebuggerUI::HaltedOnError);
+ emit updateStatus(DebuggerUI::HaltedOnError);
}
// We came across a hard coded breakpoint
else if(m_command == "forcebreak")
{
setExecutionState(Pause);
- emit updatetqStatus(DebuggerUI::HaltedOnBreakpoint);
- debuggerInterface()->showtqStatus(i18n("Breakpoint reached"), true);
+ emit updateStatus(DebuggerUI::HaltedOnBreakpoint);
+ debuggerInterface()->showStatus(i18n("Breakpoint reached"), true);
}
// A conditional breakpoint was fulfilled
else if(m_command == "conditionalbreak")
{
setExecutionState(Pause);
- emit updatetqStatus(DebuggerUI::HaltedOnBreakpoint);
- debuggerInterface()->showtqStatus(i18n("Conditional breakpoint fulfilled"), true);
+ emit updateStatus(DebuggerUI::HaltedOnBreakpoint);
+ debuggerInterface()->showStatus(i18n("Conditional breakpoint fulfilled"), true);
}
// There is a breakpoint set in this file/line
else if(m_command == "removebreakpoint")
@@ -516,7 +516,7 @@ void QuantaDebuggerGubed::processCommand(const TQString& datas)
// We're about to debug a file..
else if(m_command == "initialize")
{
- debuggerInterface()->showtqStatus(i18n("Established connection to %1").tqarg(args["filename"]), false);
+ debuggerInterface()->showStatus(i18n("Established connection to %1").arg(args["filename"]), false);
sendCommand("sendprotocolversion", (char*)0L);
debuggerInterface()->setActiveLine(mapServerPathToLocal(args["filename"]), 0);
@@ -549,7 +549,7 @@ void QuantaDebuggerGubed::processCommand(const TQString& datas)
// Reached en of an include
else if(m_command == "end")
{
- //debuggerInterface()->showtqStatus(i18n("At end of include %1").tqarg(data), true);
+ //debuggerInterface()->showStatus(i18n("At end of include %1").arg(data), true);
return;
}
// Check protocol version
@@ -557,7 +557,7 @@ void QuantaDebuggerGubed::processCommand(const TQString& datas)
{
if(args["version"] != protocolversion)
{
- debuggerInterface()->showtqStatus(i18n("The script being debugged does not communicate with the correct protocol version"), true);
+ debuggerInterface()->showStatus(i18n("The script being debugged does not communicate with the correct protocol version"), true);
sendCommand("die", (char*)0L);
}
return;
@@ -603,7 +603,7 @@ bool QuantaDebuggerGubed::sendCommand(const TQString& command, StringMap args)
TQString buffer = phpSerialize(args);
- buffer = TQString(command + ":%1;" + buffer).tqarg(buffer.length());
+ buffer = TQString(command + ":%1;" + buffer).arg(buffer.length());
m_socket->writeBlock(buffer.ascii(), buffer.length());
return true;
}
@@ -995,7 +995,7 @@ TQString QuantaDebuggerGubed::phpSerialize(StringMap args)
{
StringMap::Iterator it;
// a:2:{s:4:"name";s:7:"Jessica";s:3:"age";s:2:"26";s:4:"test";i:1;}
- TQString ret = TQString("a:%1:{").tqarg(args.size());
+ TQString ret = TQString("a:%1:{").arg(args.size());
for( it = args.begin(); it != args.end(); ++it )
{
bool isNumber;
@@ -1003,15 +1003,15 @@ TQString QuantaDebuggerGubed::phpSerialize(StringMap args)
it.data().toInt(&isNumber);
if(isNumber && !it.data().isEmpty())
ret += TQString("s:%1:\"%2\";i:%3;")
- .tqarg(it.key().length())
- .tqarg(it.key())
- .tqarg(it.data());
+ .arg(it.key().length())
+ .arg(it.key())
+ .arg(it.data());
else
ret += TQString("s:%1:\"%2\";s:%3:\"%4\";")
- .tqarg(it.key().length())
- .tqarg(it.key())
- .tqarg(it.data().length())
- .tqarg(it.data());
+ .arg(it.key().length())
+ .arg(it.key())
+ .arg(it.data().length())
+ .arg(it.data());
}
diff --git a/quanta/components/debugger/gubed/quantadebuggergubed.h b/quanta/components/debugger/gubed/quantadebuggergubed.h
index 4663d9fa..d041e90d 100644
--- a/quanta/components/debugger/gubed/quantadebuggergubed.h
+++ b/quanta/components/debugger/gubed/quantadebuggergubed.h
@@ -148,7 +148,7 @@ class QuantaDebuggerGubed : public DebuggerClient
void slotReadyAccept();
signals:
- void updatetqStatus(DebuggerUI::DebuggertqStatus);
+ void updateStatus(DebuggerUI::DebuggerStatus);
};
#endif
diff --git a/quanta/components/debugger/interfaces/debuggerclient.cpp b/quanta/components/debugger/interfaces/debuggerclient.cpp
index 88b5460e..97140dbb 100644
--- a/quanta/components/debugger/interfaces/debuggerclient.cpp
+++ b/quanta/components/debugger/interfaces/debuggerclient.cpp
@@ -43,7 +43,7 @@ bool DebuggerClient::isActive()
void DebuggerClient::unSupportedAction(const TQString &action)
{
- KMessageBox::error(NULL, i18n("The current debugger, %1, does not support the \"%2\" instruction.").tqarg(this->getName()).tqarg(action), i18n("Unsupported Debugger Function"));
+ KMessageBox::error(NULL, i18n("The current debugger, %1, does not support the \"%2\" instruction.").arg(this->getName()).arg(action), i18n("Unsupported Debugger Function"));
}
@@ -129,7 +129,7 @@ void DebuggerClient::removeBreakpoint(DebuggerBreakpoint*)
// Unimplemented defaults
void DebuggerClient::showConfig(TQDomNode)
{
- KMessageBox::error(NULL, i18n("%1 does not have any specific settings.").tqarg(this->getName()), i18n("Settings"));
+ KMessageBox::error(NULL, i18n("%1 does not have any specific settings.").arg(this->getName()), i18n("Settings"));
}
// Unimplemented defaults
@@ -141,20 +141,20 @@ void DebuggerClient::readConfig(TQDomNode)
// Unimplemented defaults: add watch
void DebuggerClient::addWatch(const TQString &)
{
- KMessageBox::error(NULL, i18n("%1 does not support watches.").tqarg(this->getName()), i18n("Unsupported Debugger Function"));
+ KMessageBox::error(NULL, i18n("%1 does not support watches.").arg(this->getName()), i18n("Unsupported Debugger Function"));
}
// Unimplemented defaults: Remove watch
void DebuggerClient::removeWatch(DebuggerVariable *)
{
// Giving an error seems pointless, since you shouldnt be able to add a watch in the first place...
- KMessageBox::error(NULL, i18n("%1 does not support watches.").tqarg(this->getName()), i18n("Unsupported Debugger Function"));
+ KMessageBox::error(NULL, i18n("%1 does not support watches.").arg(this->getName()), i18n("Unsupported Debugger Function"));
}
// Unimplemented defaults: set value of varialbe
void DebuggerClient::variableSetValue(const DebuggerVariable &)
{
- KMessageBox::error(NULL, i18n("%1 does not support setting the value of variables.").tqarg(this->getName()), i18n("Unsupported Debugger Function"));
+ KMessageBox::error(NULL, i18n("%1 does not support setting the value of variables.").arg(this->getName()), i18n("Unsupported Debugger Function"));
}
#include "debuggerclient.moc"
diff --git a/quanta/components/debugger/interfaces/debuggerclient.h b/quanta/components/debugger/interfaces/debuggerclient.h
index 317ff3e3..69ba5650 100644
--- a/quanta/components/debugger/interfaces/debuggerclient.h
+++ b/quanta/components/debugger/interfaces/debuggerclient.h
@@ -109,7 +109,7 @@ class DebuggerClient : public TQObject
DebuggerInterface *debuggerInterface();
signals:
- void updatetqStatus(DebuggerUI::DebuggertqStatus);
+ void updateStatus(DebuggerUI::DebuggerStatus);
};
diff --git a/quanta/components/debugger/interfaces/debuggerinterface.h b/quanta/components/debugger/interfaces/debuggerinterface.h
index dabd685d..cf634884 100644
--- a/quanta/components/debugger/interfaces/debuggerinterface.h
+++ b/quanta/components/debugger/interfaces/debuggerinterface.h
@@ -44,7 +44,7 @@ class DebuggerInterface : public TQObject
virtual void havenoBreakpoint (const TQString& file, int line) = 0;
// Public help functions
- virtual bool showtqStatus(const TQString& message, bool log) = 0;
+ virtual bool showStatus(const TQString& message, bool log) = 0;
virtual bool setActiveLine (const TQString& file, int line) = 0;
virtual void enableAction(const TQString& action, bool enable) = 0;
diff --git a/quanta/components/debugger/pathmapper.cpp b/quanta/components/debugger/pathmapper.cpp
index 96e4f628..c38e2fec 100644
--- a/quanta/components/debugger/pathmapper.cpp
+++ b/quanta/components/debugger/pathmapper.cpp
@@ -43,7 +43,7 @@ TQString PathMapper::translate(const TQString & path, const TQString & from, con
TQString translated = path;
// Check if this dir is matched by the maps
- if(path.tqstartsWith(from, false))
+ if(path.startsWith(from, false))
{
translated.remove(0, from.length());
translated = to + translated;
diff --git a/quanta/components/debugger/pathmapperdialog.cpp b/quanta/components/debugger/pathmapperdialog.cpp
index 671bb871..7f6f4027 100644
--- a/quanta/components/debugger/pathmapperdialog.cpp
+++ b/quanta/components/debugger/pathmapperdialog.cpp
@@ -69,7 +69,7 @@ void PathMapperDialog::slotPathsChanged()
translated = m_path;
// Check if this dir is matched by the maps
- if(m_path.tqstartsWith(from, false))
+ if(m_path.startsWith(from, false))
{
translated.remove(0, from.length());
translated = to + translated;
diff --git a/quanta/components/debugger/pathmapperdialogs.ui b/quanta/components/debugger/pathmapperdialogs.ui
index c0f27c04..58a79167 100644
--- a/quanta/components/debugger/pathmapperdialogs.ui
+++ b/quanta/components/debugger/pathmapperdialogs.ui
@@ -109,7 +109,7 @@ The quanta will know that files starting with "/home/user/project/" on the local
<property name="sizeType">
<enum>Expanding</enum>
</property>
- <property name="tqsizeHint">
+ <property name="sizeHint">
<size>
<width>20</width>
<height>20</height>
@@ -251,13 +251,13 @@ The quanta will know that files starting with "/home/user/project/" on the local
<property name="name">
<cstring>ledTranslationExists</cstring>
</property>
- <property name="tqminimumSize">
+ <property name="minimumSize">
<size>
<width>22</width>
<height>22</height>
</size>
</property>
- <property name="tqmaximumSize">
+ <property name="maximumSize">
<size>
<width>22</width>
<height>22</height>
diff --git a/quanta/components/debugger/quantadebuggerinterface.cpp b/quanta/components/debugger/quantadebuggerinterface.cpp
index 385849a5..af70da0a 100644
--- a/quanta/components/debugger/quantadebuggerinterface.cpp
+++ b/quanta/components/debugger/quantadebuggerinterface.cpp
@@ -52,9 +52,9 @@ void QuantaDebuggerInterface::havenoBreakpoint (const TQString& file, int line)
}
// Public help functions
-bool QuantaDebuggerInterface::showtqStatus(const TQString& message, bool log)
+bool QuantaDebuggerInterface::showStatus(const TQString& message, bool log)
{
- return m_manager->showtqStatus(message, log);
+ return m_manager->showStatus(message, log);
}
bool QuantaDebuggerInterface::setActiveLine(const TQString& file, int line)
diff --git a/quanta/components/debugger/quantadebuggerinterface.h b/quanta/components/debugger/quantadebuggerinterface.h
index 9c2ba724..5b9b5480 100644
--- a/quanta/components/debugger/quantadebuggerinterface.h
+++ b/quanta/components/debugger/quantadebuggerinterface.h
@@ -43,7 +43,7 @@ class QuantaDebuggerInterface : public DebuggerInterface
void refreshBreakpoints();
// Public help functions
- bool showtqStatus(const TQString& message, bool log);
+ bool showStatus(const TQString& message, bool log);
bool setActiveLine (const TQString& file, int line) ;
void enableAction(const TQString& action, bool enable);
diff --git a/quanta/components/debugger/variableslistview.cpp b/quanta/components/debugger/variableslistview.cpp
index 72e4afa3..b8a6847b 100644
--- a/quanta/components/debugger/variableslistview.cpp
+++ b/quanta/components/debugger/variableslistview.cpp
@@ -21,7 +21,7 @@
#include <kiconloader.h>
#include <tdeversion.h>
#include <kinputdialog.h>
-#include <tqclipboard.h>
+#include <clipboard.h>
// Quanta includes
#include "variableslistview.h"
@@ -39,7 +39,7 @@ namespace VariablesListViewColumns
enum Columns
{
Name = 0,
- tqStatus,
+ Status,
Value,
Type,
Size
@@ -160,7 +160,7 @@ void VariablesListView::replaceVariable(DebuggerVariable* oldvar, DebuggerVariab
{
KListViewItem * item;
- // Remove tqchildren that doesen't exist anymore
+ // Remove children that doesen't exist anymore
TQPtrList<DebuggerVariable> oldlist = oldvar->values();
for(DebuggerVariable* oldchild = oldlist.last(); oldchild; oldchild = oldlist.prev())
{
@@ -178,7 +178,7 @@ void VariablesListView::replaceVariable(DebuggerVariable* oldvar, DebuggerVariab
oldvar->deleteChild(oldchild);
}
- // Update and add tqchildren
+ // Update and add children
TQPtrList<DebuggerVariable> newlist = newvar->values();
for(DebuggerVariable* newchild = newlist.last(); newchild; newchild = newlist.prev())
{
@@ -206,9 +206,9 @@ void VariablesListView::replaceVariable(DebuggerVariable* oldvar, DebuggerVariab
item = oldvar->item();
if(oldvar->value() != newvar->value())
- item->setPixmap(VariablesListViewColumns::tqStatus, SmallIcon("ok"));
+ item->setPixmap(VariablesListViewColumns::Status, SmallIcon("ok"));
else
- item->setPixmap(VariablesListViewColumns::tqStatus, KPixmap());
+ item->setPixmap(VariablesListViewColumns::Status, KPixmap());
oldvar->copy(newvar, false);
@@ -274,7 +274,7 @@ void VariablesListView::slotVariableDump( )
if(!v)
return;
- quantaApp->messageOutput()->showMessage(i18n("Contents of variable %1:\n>>>\n").tqarg(v->name()));
+ quantaApp->messageOutput()->showMessage(i18n("Contents of variable %1:\n>>>\n").arg(v->name()));
quantaApp->messageOutput()->showMessage(v->value());
quantaApp->messageOutput()->showMessage("<<<\n");
}
@@ -284,7 +284,7 @@ void VariablesListView::slotVariableCopyToClipboard( )
DebuggerVariable *v = selected(true);
if(!v)
return;
- TQApplication::tqclipboard()->setText(v->value());
+ TQApplication::clipboard()->setText(v->value());
}
#include "variableslistview.moc"
diff --git a/quanta/components/framewizard/areaattributedb.h b/quanta/components/framewizard/areaattributedb.h
index 528da3ea..79e105be 100644
--- a/quanta/components/framewizard/areaattributedb.h
+++ b/quanta/components/framewizard/areaattributedb.h
@@ -29,7 +29,7 @@ class areaAttribute : public TQObject{
TQ_OBJECT
private:
- TQRect m_tqgeometry;
+ TQRect m_geometry;
TQMap<TQString,TQString> m_attributeMap; //tag specific attributes
public:
@@ -38,13 +38,13 @@ class areaAttribute : public TQObject{
void setAttribute(const TQString& name, const TQString& value){ m_attributeMap[name] = value; }
void setAllAttributes(TQMap<TQString,TQString> map){ m_attributeMap = map; }
void resetAttributes();
- TQRect tqgeometry() const { return m_tqgeometry; }
+ TQRect geometry() const { return m_geometry; }
TQString src() const{ return m_attributeMap["src"]; }
TQString attributeValue(TQString l) const { return attributeMap()[l];}
TQMap<TQString,TQString> attributeMap() const { return m_attributeMap; }
public slots:
- void setGeometry(TQRect g) { m_tqgeometry = g; }
+ void setGeometry(TQRect g) { m_geometry = g; }
};
#endif
diff --git a/quanta/components/framewizard/fmfpeditors.ui b/quanta/components/framewizard/fmfpeditors.ui
index 46a5354a..3e024de5 100644
--- a/quanta/components/framewizard/fmfpeditors.ui
+++ b/quanta/components/framewizard/fmfpeditors.ui
@@ -43,7 +43,7 @@
<property name="sizeType">
<enum>Expanding</enum>
</property>
- <property name="tqsizeHint">
+ <property name="sizeHint">
<size>
<width>55</width>
<height>0</height>
@@ -510,7 +510,7 @@
<property name="sizeType">
<enum>Expanding</enum>
</property>
- <property name="tqsizeHint">
+ <property name="sizeHint">
<size>
<width>20</width>
<height>40</height>
diff --git a/quanta/components/framewizard/fmrceditors.ui b/quanta/components/framewizard/fmrceditors.ui
index e0a8926c..c977d86f 100644
--- a/quanta/components/framewizard/fmrceditors.ui
+++ b/quanta/components/framewizard/fmrceditors.ui
@@ -20,13 +20,13 @@
<verstretch>0</verstretch>
</sizepolicy>
</property>
- <property name="tqminimumSize">
+ <property name="minimumSize">
<size>
<width>300</width>
<height>150</height>
</size>
</property>
- <property name="tqmaximumSize">
+ <property name="maximumSize">
<size>
<width>300</width>
<height>150</height>
@@ -104,7 +104,7 @@
<property name="sizeType">
<enum>Expanding</enum>
</property>
- <property name="tqsizeHint">
+ <property name="sizeHint">
<size>
<width>31</width>
<height>0</height>
diff --git a/quanta/components/framewizard/framewizards.ui b/quanta/components/framewizard/framewizards.ui
index cde1611f..3a3a1efd 100644
--- a/quanta/components/framewizard/framewizards.ui
+++ b/quanta/components/framewizard/framewizards.ui
@@ -20,13 +20,13 @@
<verstretch>0</verstretch>
</sizepolicy>
</property>
- <property name="tqminimumSize">
+ <property name="minimumSize">
<size>
<width>0</width>
<height>0</height>
</size>
</property>
- <property name="tqmaximumSize">
+ <property name="maximumSize">
<size>
<width>32767</width>
<height>32767</height>
@@ -77,7 +77,7 @@
<property name="sizeType">
<enum>Expanding</enum>
</property>
- <property name="tqsizeHint">
+ <property name="sizeHint">
<size>
<width>30</width>
<height>0</height>
@@ -161,7 +161,7 @@
<property name="sizeType">
<enum>Expanding</enum>
</property>
- <property name="tqsizeHint">
+ <property name="sizeHint">
<size>
<width>0</width>
<height>30</height>
@@ -221,7 +221,7 @@
<property name="sizeType">
<enum>Expanding</enum>
</property>
- <property name="tqsizeHint">
+ <property name="sizeHint">
<size>
<width>0</width>
<height>16</height>
@@ -295,7 +295,7 @@
<property name="sizeType">
<enum>Expanding</enum>
</property>
- <property name="tqsizeHint">
+ <property name="sizeHint">
<size>
<width>0</width>
<height>30</height>
diff --git a/quanta/components/framewizard/selectablearea.cpp b/quanta/components/framewizard/selectablearea.cpp
index 80c7aa00..c168e323 100644
--- a/quanta/components/framewizard/selectablearea.cpp
+++ b/quanta/components/framewizard/selectablearea.cpp
@@ -44,7 +44,7 @@ bool SelectableArea::eventFilter(TQObject *o, TQEvent *event){
}
break;
case TQEvent::Resize : {
- emit Resized( view()->tqgeometry() );
+ emit Resized( view()->geometry() );
view()->hide();
view()->show();
return true;
diff --git a/quanta/components/framewizard/treenode.cpp b/quanta/components/framewizard/treenode.cpp
index 2faaf3d6..fd1f187f 100644
--- a/quanta/components/framewizard/treenode.cpp
+++ b/quanta/components/framewizard/treenode.cpp
@@ -20,7 +20,7 @@
static const int SIZE = 101;
treeNode::treeNode(const TQString &l, const TQString &pl) : m_label(l), m_parentLabel(pl), m_splitType(NONE){
- m_tqchildrenList.setAutoDelete(true);
+ m_childrenList.setAutoDelete(true);
m_atts = new areaAttribute;
}
@@ -29,16 +29,16 @@ treeNode::~treeNode(){
}
void treeNode::addChildNode(const TQString &l) {
- m_tqchildrenList.append( new treeNode(l,m_label) );
+ m_childrenList.append( new treeNode(l,m_label) );
}
void treeNode::removeChildNode(const TQString &l,bool autoDelete) {
- m_tqchildrenList.setAutoDelete(autoDelete);
- m_tqchildrenList.remove(findChild(l));
+ m_childrenList.setAutoDelete(autoDelete);
+ m_childrenList.remove(findChild(l));
}
treeNode* treeNode::findChild(const TQString &l){
- TQPtrListIterator<treeNode> it( m_tqchildrenList );
+ TQPtrListIterator<treeNode> it( m_childrenList );
treeNode *node;
while ( (node = it.current()) != 0 ) {
++it;
@@ -68,25 +68,25 @@ void tree::refreshGeometries(treeNode *n){
n->nextChild();
}
- TQPtrList<treeNode> list = n->tqchildrenList();
+ TQPtrList<treeNode> list = n->childrenList();
TQPtrListIterator<treeNode> it( list );
treeNode *node= it.current();
- TQRect newGeometry = n->atts()->tqgeometry();
+ TQRect newGeometry = n->atts()->geometry();
if(n->splitType()==VERTICAL){
- newGeometry.setHeight(node->atts()->tqgeometry().height());
+ newGeometry.setHeight(node->atts()->geometry().height());
while ( (node = it.current()) != 0 ) {
++it;
- dim += node->atts()->tqgeometry().width();
+ dim += node->atts()->geometry().width();
dim += 6;
}
newGeometry.setWidth(dim);
}
else
if(n->splitType()==HORIZONTAL){
- newGeometry.setWidth(node->atts()->tqgeometry().width());
+ newGeometry.setWidth(node->atts()->geometry().width());
while ( (node = it.current()) != 0 ) {
++it;
- dim += node->atts()->tqgeometry().height();
+ dim += node->atts()->geometry().height();
dim += 6;
}
newGeometry.setHeight(dim);
diff --git a/quanta/components/framewizard/treenode.h b/quanta/components/framewizard/treenode.h
index c96d9b17..82d312fb 100644
--- a/quanta/components/framewizard/treenode.h
+++ b/quanta/components/framewizard/treenode.h
@@ -33,36 +33,36 @@ class treeNode {
TQString m_label,
m_parentLabel;
SplitType m_splitType;
- TQPtrList<treeNode> m_tqchildrenList;
+ TQPtrList<treeNode> m_childrenList;
areaAttribute *m_atts;
public:
treeNode(const TQString &l=TQString(), const TQString &pl=TQString());
~treeNode();
void addChildNode(const TQString &L);
- void addChildNode(treeNode *n){ m_tqchildrenList.append(n); }
+ void addChildNode(treeNode *n){ m_childrenList.append(n); }
void removeChildNode(const TQString &l, bool autoDelete);
void setSplitType(SplitType s) { m_splitType = s; }
void setLabel(const TQString &l) { m_label = l; }
- void removeChildren() { m_tqchildrenList.clear(); }
+ void removeChildren() { m_childrenList.clear(); }
void setParentLabel(const TQString &s){ m_parentLabel = s;}
- int childPosition(treeNode* n){ return m_tqchildrenList.find(n); }
- bool insertChild(unsigned int pos, treeNode* n) { return m_tqchildrenList.insert( pos, n); }
+ int childPosition(treeNode* n){ return m_childrenList.find(n); }
+ bool insertChild(unsigned int pos, treeNode* n) { return m_childrenList.insert( pos, n); }
TQString label() const { return m_label; }
TQString parentLabel() const { return m_parentLabel; }
SplitType splitType() const { return m_splitType; }
- TQPtrList<treeNode> tqchildrenList() { return m_tqchildrenList; }
+ TQPtrList<treeNode> childrenList() { return m_childrenList; }
- treeNode* firstChild() { return m_tqchildrenList.first(); }
- treeNode* nextChild() { return m_tqchildrenList.next(); }
- treeNode* lastChild() { return m_tqchildrenList.last(); }
- treeNode* currentChild() { return m_tqchildrenList.current(); }
+ treeNode* firstChild() { return m_childrenList.first(); }
+ treeNode* nextChild() { return m_childrenList.next(); }
+ treeNode* lastChild() { return m_childrenList.last(); }
+ treeNode* currentChild() { return m_childrenList.current(); }
treeNode* findChild(const TQString &L);
areaAttribute* atts() { return m_atts; }
- int countChildren() const { return m_tqchildrenList.count(); }
- bool hasChildren() const { return !m_tqchildrenList.isEmpty(); }
+ int countChildren() const { return m_childrenList.count(); }
+ bool hasChildren() const { return !m_childrenList.isEmpty(); }
};
class tree{
diff --git a/quanta/components/framewizard/visualframeeditor.cpp b/quanta/components/framewizard/visualframeeditor.cpp
index e822d7e0..4b1f62f3 100644
--- a/quanta/components/framewizard/visualframeeditor.cpp
+++ b/quanta/components/framewizard/visualframeeditor.cpp
@@ -46,12 +46,12 @@ VisualFrameEditor::~VisualFrameEditor(){
void VisualFrameEditor::setGeometries(const TQString &l){
int cP = cancelledPixels(m_internalTree->findNode(l)->countChildren());
- TQRect newGeometry(m_internalTree->findNode(l)->atts()->tqgeometry());
- TQPtrList<treeNode> list=m_internalTree->findNode(l)->tqchildrenList();
+ TQRect newGeometry(m_internalTree->findNode(l)->atts()->geometry());
+ TQPtrList<treeNode> list=m_internalTree->findNode(l)->childrenList();
TQPtrListIterator<treeNode> it( list );
treeNode *node;
if(m_internalTree->findNode(l)->splitType() == VERTICAL){
- int dummyDimension=m_internalTree->findNode(l)->atts()->tqgeometry().width()-cP;
+ int dummyDimension=m_internalTree->findNode(l)->atts()->geometry().width()-cP;
while ( (node = it.current()) != 0 ) {
++it;
newGeometry.setWidth( int(dummyDimension/m_internalTree->findNode(l)->countChildren()) );
@@ -60,7 +60,7 @@ void VisualFrameEditor::setGeometries(const TQString &l){
}
else
if(m_internalTree->findNode(l)->splitType() == HORIZONTAL){
- int dummyDimension=m_internalTree->findNode(l)->atts()->tqgeometry().height()-cP;
+ int dummyDimension=m_internalTree->findNode(l)->atts()->geometry().height()-cP;
while ( (node = it.current()) != 0 ) {
++it;
newGeometry.setHeight( int(dummyDimension/m_internalTree->findNode(l)->countChildren()) );
@@ -145,12 +145,12 @@ void VisualFrameEditor::buildInternalTree(const TQString &parent){
TQRegExp pattern("rows\\s*=\"([\\s\\d%,\\*]*)\"");
pattern.search(line);
- TQRect dummy=m_internalTree->findNode(parent)->atts()->tqgeometry();
+ TQRect dummy=m_internalTree->findNode(parent)->atts()->geometry();
TQStringList percentages = convertAsterisks(pattern.cap(1),dummy.height());
int dummyDimension=dummy.height()-cancelledPixels(line.contains(",")+1);
- TQPtrList<treeNode> list=m_internalTree->findNode(parent)->tqchildrenList();
+ TQPtrList<treeNode> list=m_internalTree->findNode(parent)->childrenList();
TQPtrListIterator<treeNode> it( list );
treeNode *node;
while ( (node = it.current()) != 0 ) {
@@ -171,12 +171,12 @@ void VisualFrameEditor::buildInternalTree(const TQString &parent){
TQRegExp pattern("cols\\s*=\"([\\s\\d%,\\*]*)\"");
pattern.search(line);
- TQRect dummy=m_internalTree->findNode(parent)->atts()->tqgeometry();
+ TQRect dummy=m_internalTree->findNode(parent)->atts()->geometry();
TQStringList percentages = convertAsterisks(pattern.cap(1),dummy.width());
int dummyDimension=dummy.width()-cancelledPixels(line.contains(",")+1);
- TQPtrList<treeNode> list=m_internalTree->findNode(parent)->tqchildrenList();
+ TQPtrList<treeNode> list=m_internalTree->findNode(parent)->childrenList();
TQPtrListIterator<treeNode> it( list );
treeNode *node;
while ( (node = it.current()) != 0 ) {
@@ -258,7 +258,7 @@ void VisualFrameEditor::removeNode(const TQString &l){
m_internalTree->findNode(parentLabel)->setSplitType(NONE);
}
else {
- TQPtrList<treeNode> list = m_internalTree->findNode(parentLabel)->firstChild()->tqchildrenList();
+ TQPtrList<treeNode> list = m_internalTree->findNode(parentLabel)->firstChild()->childrenList();
if( parentLabel != m_internalTree->root()->label() ) {
TQString grandParentLabel = m_internalTree->findNode(parentLabel)->parentLabel();
m_internalTree->removeChildNode( parentLabel,m_internalTree->findNode(parentLabel)->firstChild()->label(),false );
@@ -304,7 +304,7 @@ void VisualFrameEditor::drawGUI(treeNode *n, TQWidget* parent){
if(parent->isA(TQSPLITTER_OBJECT_NAME_STRING)) dynamic_cast<TQSplitter *>(parent)->setResizeMode(sa->view(),TQSplitter::KeepSize );
else
if(!m_firstInsertedSA) m_firstInsertedSA = sa;
- sa->view()->setGeometry(n->atts()->tqgeometry());
+ sa->view()->setGeometry(n->atts()->geometry());
sa->setIdLabel( n->label() );
sa->setSource( n->atts()->src() );
connect(sa, TQT_SIGNAL(Resized(TQRect)), m_internalTree->findNode(sa->idLabel())->atts(), TQT_SLOT(setGeometry(TQRect)));
@@ -371,11 +371,11 @@ TQString VisualFrameEditor::RCvalue(treeNode *n) {
int lostPixels = (6*(child_number-1)); // 6 pixels are lost every time a splitter is drawn
switch( n->splitType() ) {
- case VERTICAL: percentage/=n->atts()->tqgeometry().width();
- for(int i=1;i<=child_number;++i) dimMap[i]=n->tqchildrenList().at(i-1)->atts()->tqgeometry().width();
+ case VERTICAL: percentage/=n->atts()->geometry().width();
+ for(int i=1;i<=child_number;++i) dimMap[i]=n->childrenList().at(i-1)->atts()->geometry().width();
break;
- case HORIZONTAL: percentage/=n->atts()->tqgeometry().height();
- for(int i=1;i<=child_number;++i) dimMap[i]=n->tqchildrenList().at(i-1)->atts()->tqgeometry().height();
+ case HORIZONTAL: percentage/=n->atts()->geometry().height();
+ for(int i=1;i<=child_number;++i) dimMap[i]=n->childrenList().at(i-1)->atts()->geometry().height();
break;
default:break;
}
diff --git a/quanta/components/framewizard/visualframeeditor.h b/quanta/components/framewizard/visualframeeditor.h
index c7338128..39bb4b4c 100644
--- a/quanta/components/framewizard/visualframeeditor.h
+++ b/quanta/components/framewizard/visualframeeditor.h
@@ -50,7 +50,7 @@ class VisualFrameEditor : public TQHBox {
public:
VisualFrameEditor( TQWidget * parent = 0, const char * name = 0);
~VisualFrameEditor();
- void draw() { tqrepaint(); }
+ void draw() { repaint(); }
void loadExistingStructure(const TQStringList &list);
TQString framesetStructure();
void removeNode(const TQString &l);
diff --git a/quanta/components/tableeditor/tableeditor.cpp b/quanta/components/tableeditor/tableeditor.cpp
index a94c15e4..45bcf07c 100644
--- a/quanta/components/tableeditor/tableeditor.cpp
+++ b/quanta/components/tableeditor/tableeditor.cpp
@@ -204,7 +204,7 @@ void TableEditor::slotEditRow()
void TableEditor::slotEditCol()
{
- KMessageBox::information(this, i18n("Edit col: %1").tqarg(m_col + 1));
+ KMessageBox::information(this, i18n("Edit col: %1").arg(m_col + 1));
TagDialog dlg(QuantaCommon::tagFromDTD(m_dtd,"col"));
dlg.exec();
}
@@ -411,7 +411,7 @@ bool TableEditor::setTableArea( int bLine, int bCol, int eLine, int eCol, Parser
m_colSpin->setValue(col);
TableNode tableN = mergeMatrix[nRow - 1][col];
Node *n = tableN.node;
- setCellText(m_dataTable, nRow - 1, col, i18n("Merged with (%1, %2).").tqarg(tableN.mergedRow + 1).tqarg(tableN.mergedCol + 1));
+ setCellText(m_dataTable, nRow - 1, col, i18n("Merged with (%1, %2).").arg(tableN.mergedRow + 1).arg(tableN.mergedCol + 1));
m_dataTable->item(nRow-1, col)->setEnabled(false);
tableNode.node = new Node(0L);
tableNode.node->tag = new Tag(*(n->tag));
@@ -451,7 +451,7 @@ bool TableEditor::setTableArea( int bLine, int bCol, int eLine, int eCol, Parser
m_colSpin->setValue(col);
TableNode tableN = mergeMatrix[nRow - 1][col];
Node *n = tableN.node;
- setCellText(m_dataTable, nRow - 1, col, i18n("Merged with (%1, %2).").tqarg(tableN.mergedRow + 1).tqarg(tableN.mergedCol + 1));
+ setCellText(m_dataTable, nRow - 1, col, i18n("Merged with (%1, %2).").arg(tableN.mergedRow + 1).arg(tableN.mergedCol + 1));
m_dataTable->item(nRow-1, col)->setEnabled(false);
tableNode.node = new Node(0L);
tableNode.node->tag = new Tag(*(n->tag));
@@ -496,7 +496,7 @@ bool TableEditor::setTableArea( int bLine, int bCol, int eLine, int eCol, Parser
m_colSpin->setValue(nCol);
for (int i = 0; i < colValue - 1; i++)
{
- setCellText(m_dataTable, nRow - 1, lastCol + i, i18n("Merged with (%1, %2).").tqarg(nRow).tqarg(lastCol));
+ setCellText(m_dataTable, nRow - 1, lastCol + i, i18n("Merged with (%1, %2).").arg(nRow).arg(lastCol));
m_dataTable->item(nRow-1, lastCol + i)->setEnabled(false);
tableNode.node = new Node(0L);
tableNode.node->tag = new Tag(*(n->tag));
@@ -924,7 +924,7 @@ void TableEditor::slotRemoveRow()
int rowspan = mainTableNode->node->tag->attributeValue("rowspan", true).toInt();
rowspan--;
if (rowspan > 1)
- mainTableNode->node->tag->editAttribute("rowspan", TQString("%1").tqarg(rowspan));
+ mainTableNode->node->tag->editAttribute("rowspan", TQString("%1").arg(rowspan));
else
mainTableNode->node->tag->deleteAttribute("rowspan");
updatedMainNodes.append(mainTableNode);
@@ -975,7 +975,7 @@ void TableEditor::slotRemoveCol()
int colspan = mainTableNode->node->tag->attributeValue("colspan", true).toInt();
colspan--;
if (colspan > 1)
- mainTableNode->node->tag->editAttribute("colspan", TQString("%1").tqarg(colspan));
+ mainTableNode->node->tag->editAttribute("colspan", TQString("%1").arg(colspan));
else
mainTableNode->node->tag->deleteAttribute("colspan");
updatedMainNodes.append(mainTableNode);
@@ -1054,13 +1054,13 @@ void TableEditor::slotMergeCells()
rCol = selection.rightCol();
TableNode *mainTableNode = &((*m_tableTags)[tRow][lCol]);
if (rCol - lCol > 0)
- mainTableNode->node->tag->editAttribute("colspan", TQString("%1").tqarg(rCol - lCol + 1));
+ mainTableNode->node->tag->editAttribute("colspan", TQString("%1").arg(rCol - lCol + 1));
if (bRow - tRow > 0)
- mainTableNode->node->tag->editAttribute("rowspan", TQString("%1").tqarg(bRow - tRow + 1));
+ mainTableNode->node->tag->editAttribute("rowspan", TQString("%1").arg(bRow - tRow + 1));
for (int i = 0; i < bRow - tRow + 1; i++)
for (int j = 0; j < rCol - lCol + 1; j++) {
if (i != 0 || j != 0) {
- setCellText(m_dataTable, tRow + i, lCol + j, i18n("Merged with (%1, %2).").tqarg(tRow + 1).tqarg(lCol + 1));
+ setCellText(m_dataTable, tRow + i, lCol + j, i18n("Merged with (%1, %2).").arg(tRow + 1).arg(lCol + 1));
m_dataTable->item(tRow + i, lCol + j)->setEnabled(false);
TableNode *tableNode = &((*m_tableTags)[tRow + i][lCol + j]);
Node::deleteNode(tableNode->node);
@@ -1271,7 +1271,7 @@ void TableEditor::configureCell(int row, int col, Node * node)
return;
// Header (TH) or standard cell?
item->setHeader(node->tag->name.lower() == "th");
- //Qt::Horizontal tqalignment
+ //Qt::Horizontal alignment
TQt::AlignmentFlags flags;
TQString align = node->tag->attributeValue("align", true);
if (align == "right")
@@ -1284,8 +1284,8 @@ void TableEditor::configureCell(int row, int col, Node * node)
flags = TQt::AlignHCenter; // TH is centered by default
else
flags = TQt::AlignLeft;
- item->tqsetAlignment(flags);
- //Qt::Vertical tqalignment
+ item->setAlignment(flags);
+ //Qt::Vertical alignment
TQString valign = node->tag->attributeValue("valign", true);
if (valign == "top")
flags = TQt::AlignTop;
diff --git a/quanta/components/tableeditor/tableeditors.ui b/quanta/components/tableeditor/tableeditors.ui
index f74a2620..29511351 100644
--- a/quanta/components/tableeditor/tableeditors.ui
+++ b/quanta/components/tableeditor/tableeditors.ui
@@ -40,7 +40,7 @@
<property name="sizeType">
<enum>Expanding</enum>
</property>
- <property name="tqsizeHint">
+ <property name="sizeHint">
<size>
<width>16</width>
<height>20</height>
@@ -142,7 +142,7 @@
<property name="sizeType">
<enum>Expanding</enum>
</property>
- <property name="tqsizeHint">
+ <property name="sizeHint">
<size>
<width>276</width>
<height>20</height>
@@ -159,7 +159,7 @@
<property name="sizeType">
<enum>Expanding</enum>
</property>
- <property name="tqsizeHint">
+ <property name="sizeHint">
<size>
<width>276</width>
<height>20</height>
@@ -313,7 +313,7 @@
<property name="sizeType">
<enum>Expanding</enum>
</property>
- <property name="tqsizeHint">
+ <property name="sizeHint">
<size>
<width>340</width>
<height>20</height>
@@ -392,7 +392,7 @@
<property name="sizeType">
<enum>Expanding</enum>
</property>
- <property name="tqsizeHint">
+ <property name="sizeHint">
<size>
<width>40</width>
<height>20</height>
@@ -528,7 +528,7 @@
<property name="sizeType">
<enum>Expanding</enum>
</property>
- <property name="tqsizeHint">
+ <property name="sizeHint">
<size>
<width>340</width>
<height>20</height>
@@ -555,7 +555,7 @@
<property name="sizeType">
<enum>Expanding</enum>
</property>
- <property name="tqsizeHint">
+ <property name="sizeHint">
<size>
<width>40</width>
<height>20</height>
diff --git a/quanta/components/tableeditor/tableitem.cpp b/quanta/components/tableeditor/tableitem.cpp
index c2f4e298..aed532d1 100644
--- a/quanta/components/tableeditor/tableitem.cpp
+++ b/quanta/components/tableeditor/tableitem.cpp
@@ -14,7 +14,7 @@
* *
***************************************************************************/
-#include <tqtextedit.h>
+#include <textedit.h>
#include <tqpainter.h>
#include "tableitem.h"
@@ -84,9 +84,9 @@ void TableItem::paint(TQPainter* p, const TQColorGroup& cg, const TQRect& cr, bo
p->drawText(4, 4, cr0.width()-8, cr0.height()-8, m_halign | m_valign | WordBreak, text());
}
-TQSize TableItem::tqsizeHint() const
+TQSize TableItem::sizeHint() const
{
- TQSize size = TQTableItem::tqsizeHint();
+ TQSize size = TQTableItem::sizeHint();
size.setWidth(size.width()+8);
size.setHeight(size.height()+8);
return size;
diff --git a/quanta/components/tableeditor/tableitem.h b/quanta/components/tableeditor/tableitem.h
index 12e2b4b0..017738bf 100644
--- a/quanta/components/tableeditor/tableitem.h
+++ b/quanta/components/tableeditor/tableitem.h
@@ -35,16 +35,16 @@ public:
virtual TQWidget* createEditor() const;
// Get text from TQTextEdit
virtual void setContentFromEditor(TQWidget *w);
- // Paint cell - handle tqalignment (horizontal and vertical) and bold for header
+ // Paint cell - handle alignment (horizontal and vertical) and bold for header
virtual void paint(TQPainter* p, const TQColorGroup& cg, const TQRect& cr, bool selected);
- // Return A bit larger tqsizeHint because TQTextEdit has some margin around
- virtual TQSize tqsizeHint() const;
+ // Return A bit larger sizeHint because TQTextEdit has some margin around
+ virtual TQSize sizeHint() const;
// Get and set vertical aligment
TQt::AlignmentFlags vAlignment() {return m_valign;}
void setVAlignment(TQt::AlignmentFlags flags) {m_valign = flags;}
// Get and set horizontal aligment
- TQt::AlignmentFlags tqalignment() {return m_halign;}
- void tqsetAlignment(TQt::AlignmentFlags flags) {m_halign = flags;}
+ TQt::AlignmentFlags alignment() {return m_halign;}
+ void setAlignment(TQt::AlignmentFlags flags) {m_halign = flags;}
// Get and set header status (use true for TH, false for TD)
bool header() {return m_header;}
void setHeader(bool h) {m_header = h;}